Compare

Trait Compare 

pub trait Compare<Rhs = Self>
where Rhs: ?Sized,
{ type Output; // Required methods fn is_less_than(&self, other: &Rhs) -> Self::Output; fn is_greater_than(&self, other: &Rhs) -> Self::Output; fn is_less_than_or_equal(&self, other: &Rhs) -> Self::Output; fn is_greater_than_or_equal(&self, other: &Rhs) -> Self::Output; }
Trait for comparator operations.

Required Associated Types

Required Methods

fn is_less_than(&self, other: &Rhs) -> Self::Output

Returns true if self is less than other.

fn is_greater_than(&self, other: &Rhs) -> Self::Output

Returns true if self is greater than other.

fn is_less_than_or_equal(&self, other: &Rhs) -> Self::Output

Returns true if self is less than or equal to other.

fn is_greater_than_or_equal(&self, other: &Rhs) -> Self::Output

Returns true if self is greater than or equal to other.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E> Compare for Address<E>
where E: Environment,

Source

impl<E> Compare for Field<E>
where E: Environment,

Source

impl<E> Compare for Scalar<E>
where E: Environment,

Source

impl<E, I> Compare for Integer<E, I>
where E: Environment, I: IntegerType,