#[non_exhaustive]pub enum FromCharError {
NotAscii(char),
Invalid(char),
}Expand description
A galois field error when converting from a character.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotAscii(char)
Tried to interpret a character as a GF32 element but it is not an ASCII character.
Invalid(char)
Tried to interpret a character as a GF32 element but it is not part of the bech32 character set.