pub trait Equal<Rhs = Self>where
Rhs: ?Sized,{
type Output;
// Required methods
fn is_equal(&self, other: &Rhs) -> Self::Output;
fn is_not_equal(&self, other: &Rhs) -> Self::Output;
}Expand description
Trait for equality comparisons.
Required Associated Types
Required Methods
Sourcefn is_not_equal(&self, other: &Rhs) -> Self::Output
fn is_not_equal(&self, other: &Rhs) -> Self::Output
Returns true if self and other are not equal.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<N> Equal for ComputeKey<N>where
N: Network,
impl<N> Equal for ComputeKey<N>where
N: Network,
Sourcefn is_equal(&self, other: &ComputeKey<N>) -> <ComputeKey<N> as Equal>::Output
fn is_equal(&self, other: &ComputeKey<N>) -> <ComputeKey<N> as Equal>::Output
Returns true if self and other are equal.
Sourcefn is_not_equal(
&self,
other: &ComputeKey<N>,
) -> <ComputeKey<N> as Equal>::Output
fn is_not_equal( &self, other: &ComputeKey<N>, ) -> <ComputeKey<N> as Equal>::Output
Returns true if self and other are not equal.