_

pub trait _: Sized + ToBits {
    // Required methods
    fn write_bits_raw_le(&self, vec: &mut Vec<bool>);
    fn write_bits_raw_be(&self, vec: &mut Vec<bool>);

    // Provided methods
    fn to_bits_raw_le(&self) -> Vec<bool> { ... }
    fn to_bits_raw_be(&self) -> Vec<bool> { ... }
}

Required Methods

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

Writes self into the given vector as a raw boolean array in little-endian order.

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

Writes self into the given vector as a boolean array in big-endian order.

Provided Methods

fn to_bits_raw_le(&self) -> Vec<bool>

Returns self as a boolean array in little-endian order.

fn to_bits_raw_be(&self) -> Vec<bool>

Returns self as a boolean array in big-endian order.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<'a, C0, C1> ToBitsRaw for &'a (C0, C1)
where C0: ToBitsRaw, C1: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2> ToBitsRaw for &'a (C0, C1, C2)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3> ToBitsRaw for &'a (C0, C1, C2, C3)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4> ToBitsRaw for &'a (C0, C1, C2, C3, C4)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw, C10: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1> ToBitsRaw for (C0, C1)
where C0: ToBitsRaw, C1: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2> ToBitsRaw for (C0, C1, C2)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3> ToBitsRaw for (C0, C1, C2, C3)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4> ToBitsRaw for (C0, C1, C2, C3, C4)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5> ToBitsRaw for (C0, C1, C2, C3, C4, C5)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw, C10: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C> ToBitsRaw for &[C]
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<C> ToBitsRaw for Vec<C>
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<C, const N: usize> ToBitsRaw for [C; N]
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Implementors

mary>
Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits from the circuits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5> ToBits for (C0, C1, C2, C3, C4, C5)
where C0: ToBits, C1: ToBits, C2: ToBits, C3: ToBits, C4: ToBits, C5: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits from the circuits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6> ToBits for (C0, C1, C2, C3, C4, C5, C6)
where C0: ToBits, C1: ToBits, C2: ToBits, C3: ToBits, C4: ToBits, C5: ToBits, C6: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits from the circuits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7> ToBits for (C0, C1, C2, C3, C4, C5, C6, C7)
where C0: ToBits, C1: ToBits, C2: ToBits, C3: ToBits, C4: ToBits, C5: ToBits, C6: ToBits, C7: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits from the circuits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBits for (C0, C1, C2, C3, C4, C5, C6, C7, C8)
where C0: ToBits, C1: ToBits, C2: ToBits, C3: ToBits, C4: ToBits, C5: ToBits, C6: ToBits, C7: ToBits, C8: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits from the circuits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBits for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
where C0: ToBits, C1: ToBits, C2: ToBits, C3: ToBits, C4: ToBits, C5: ToBits, C6: ToBits, C7: ToBits, C8: ToBits, C9: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits from the circuits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBits for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
where C0: ToBits, C1: ToBits, C2: ToBits, C3: ToBits, C4: ToBits, C5: ToBits, C6: ToBits, C7: ToBits, C8: ToBits, C9: ToBits, C10: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits from the circuits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits from the circuits.

Source

impl<C> ToBits for &[C]
where C: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<C> ToBits for Vec<C>
where C: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<C, const N: usize> ToBits for [C; N]
where C: ToBits,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<N> ToBits for ComputeKey<N>
where N: Network,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

Returns the little-endian bits of the compute key.

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

Returns the big-endian bits of the compute key.

Source

impl<P> ToBits for Fp2<P>
where P: Fp2Parameters,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

Source

impl<P> ToBits for Fp6<P>
where P: Fp6Parameters,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

Source

impl<P> ToBits for Fp12<P>
where P: Fp12Parameters,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

Source

impl<P> ToBits for Fp256<P>
where P: Fp256Parameters,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

Source

fn num_bits() -> Option<usize>

Source

impl<P> ToBits for Fp384<P>
where P: Fp384Parameters,

Source

fn write_bits_le(&self, vec: &mut Vec<bool>)

Source

fn write_bits_be(&self, vec: &mut Vec<bool>)

Source

fn num_bits() -> Option<usize>

Implementors

Source

impl ToBits for BigInteger256

Source

impl ToBits for BigInteger384

Source

impl<E> ToBits for Address<E>
where E: Environment,

Source

impl<E> ToBits for Boolean<E>
where E: Environment,

Source

impl<E> ToBits for Field<E>
where E: Environment,

Source

impl<E> ToBits for Group<E>
where E: Environment,

Source

impl<E> ToBits for IdentifierLiteral<E>
where E: Environment,

Source

impl<E> ToBits for Scalar<E>
where E: Environment,

Source

impl<E, I> ToBits for Integer<E, I>
where E: Environment, I: IntegerType,

Source

impl<N> ToBits for Signature<N>
where N: Network,

Source

impl<N: Network> ToBits for &Literal<N>

Source

impl<N: Network> ToBits for &Identifier<N>

Source

impl<N: Network> ToBits for &ProgramID<N>

Source

impl<N: Network> ToBits for Argument<N>

Source

impl<N: Network> ToBits for Entry<N, Plaintext<N>>

Source

impl<N: Network> ToBits for Entry<N, Ciphertext<N>>

Source

impl<N: Network> ToBits for Literal<N>

Source

impl<N: Network> ToBits for Plaintext<N>

Source

impl<N: Network> ToBits for Value<N>

Source

impl<N: Network> ToBits for HeaderLeaf<N>

Source

impl<N: Network> ToBits for TransactionLeaf<N>

Source

impl<N: Network> ToBits for TransitionLeaf<N>

Source

impl<N: Network> ToBits for Ciphertext<N>

Source

impl<N: Network> ToBits for DynamicFuture<N>

Source

impl<N: Network> ToBits for DynamicRecord<N>

Source

impl<N: Network> ToBits for Future<N>

Source

impl<N: Network> ToBits for Identifier<N>

Source

impl<N: Network> ToBits for ProgramID<N>

Source

impl<N: Network> ToBits for Record<N, Plaintext<N>>

Source

impl<N: Network> ToBits for Record<N, Ciphertext<N>>