pub trait CommitUncompressed {
type Input;
type Output;
type Randomizer;
// Required method
fn commit_uncompressed(
&self,
input: &[Self::Input],
randomizer: &Self::Randomizer,
) -> Result<Self::Output, Error>;
}Expand description
A trait for a commitment scheme.
Required Associated Types
Required Methods
Sourcefn commit_uncompressed(
&self,
input: &[Self::Input],
randomizer: &Self::Randomizer,
) -> Result<Self::Output, Error>
fn commit_uncompressed( &self, input: &[Self::Input], randomizer: &Self::Randomizer, ) -> Result<Self::Output, Error>
Returns the commitment to the given input and randomizer.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<E, const NUM_BITS: u8> CommitUncompressed for Pedersen<E, NUM_BITS>where
E: Environment,
impl<E, const NUM_BITS: u8> CommitUncompressed for Pedersen<E, NUM_BITS>where
E: Environment,
Sourcefn commit_uncompressed(
&self,
input: &[<Pedersen<E, NUM_BITS> as CommitUncompressed>::Input],
randomizer: &<Pedersen<E, NUM_BITS> as CommitUncompressed>::Randomizer,
) -> Result<<Pedersen<E, NUM_BITS> as CommitUncompressed>::Output, Error>
fn commit_uncompressed( &self, input: &[<Pedersen<E, NUM_BITS> as CommitUncompressed>::Input], randomizer: &<Pedersen<E, NUM_BITS> as CommitUncompressed>::Randomizer, ) -> Result<<Pedersen<E, NUM_BITS> as CommitUncompressed>::Output, Error>
Returns the Pedersen commitment of the given input and randomizer as a group element.
type Input = bool
type Output = Group<E>
type Randomizer = Scalar<E>
Sourceimpl<E, const NUM_WINDOWS: u8, const WINDOW_SIZE: u8> CommitUncompressed for BHP<E, NUM_WINDOWS, WINDOW_SIZE>where
E: Environment,
impl<E, const NUM_WINDOWS: u8, const WINDOW_SIZE: u8> CommitUncompressed for BHP<E, NUM_WINDOWS, WINDOW_SIZE>where
E: Environment,
Sourcefn commit_uncompressed(
&self,
input: &[<BHP<E, NUM_WINDOWS, WINDOW_SIZE> as CommitUncompressed>::Input],
randomizer: &<BHP<E, NUM_WINDOWS, WINDOW_SIZE> as CommitUncompressed>::Randomizer,
) -> Result<<BHP<E, NUM_WINDOWS, WINDOW_SIZE> as CommitUncompressed>::Output, Error>
fn commit_uncompressed( &self, input: &[<BHP<E, NUM_WINDOWS, WINDOW_SIZE> as CommitUncompressed>::Input], randomizer: &<BHP<E, NUM_WINDOWS, WINDOW_SIZE> as CommitUncompressed>::Randomizer, ) -> Result<<BHP<E, NUM_WINDOWS, WINDOW_SIZE> as CommitUncompressed>::Output, Error>
Returns the BHP commitment of the given input and randomizer as an affine group element.