_

Trait _ 

pub trait _: Sized + ToBits {
    // Required methods
    fn write_bits_raw_le(&self, vec: &mut Vec<bool>);
    fn write_bits_raw_be(&self, vec: &mut Vec<bool>);

    // Provided methods
    fn to_bits_raw_le(&self) -> Vec<bool> { ... }
    fn to_bits_raw_be(&self) -> Vec<bool> { ... }
}

Required Methods

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

Writes self into the given vector as a raw boolean array in little-endian order.

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

Writes self into the given vector as a boolean array in big-endian order.

Provided Methods

fn to_bits_raw_le(&self) -> Vec<bool>

Returns self as a boolean array in little-endian order.

fn to_bits_raw_be(&self) -> Vec<bool>

Returns self as a boolean array in big-endian order.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<'a, C0, C1> ToBitsRaw for &'a (C0, C1)
where C0: ToBitsRaw, C1: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2> ToBitsRaw for &'a (C0, C1, C2)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3> ToBitsRaw for &'a (C0, C1, C2, C3)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4> ToBitsRaw for &'a (C0, C1, C2, C3, C4)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw, C10: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1> ToBitsRaw for (C0, C1)
where C0: ToBitsRaw, C1: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2> ToBitsRaw for (C0, C1, C2)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3> ToBitsRaw for (C0, C1, C2, C3)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4> ToBitsRaw for (C0, C1, C2, C3, C4)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5> ToBitsRaw for (C0, C1, C2, C3, C4, C5)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw, C10: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C> ToBitsRaw for &[C]
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<C> ToBitsRaw for Vec<C>
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<C, const N: usize> ToBitsRaw for [C; N]
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Implementors

ss="trait" href="../address/trait._.html" title="trait snarkvm_console_program::address::_">Hash for Fields
Source

impl Hash for icu_locale_core::extensions::transform::key::Key

Source

impl Hash for Transform

Source

impl Hash for icu_locale_core::extensions::transform::value::Value

Source

impl Hash for Attribute

Source

impl Hash for Attributes

Source

impl Hash for icu_locale_core::extensions::unicode::key::Key

Source

impl Hash for Keywords

Source

impl Hash for Unicode

Source

impl Hash for SubdivisionId

Source

impl Hash for SubdivisionSuffix

Source

impl Hash for icu_locale_core::extensions::unicode::value::Value

Source

impl Hash for LanguageIdentifier

Source

impl Hash for Locale

Source

impl Hash for CurrencyType

Source

impl Hash for NumberingSystem

Source

impl Hash for RegionOverride

Source

impl Hash for RegionalSubdivision

Source

impl Hash for TimeZoneShortId

Source

impl Hash for LocalePreferences

Source

impl Hash for Language

Source

impl Hash for Region

Source

impl Hash for icu_locale_core::subtags::script::Script

Source

impl Hash for icu_locale_core::subtags::Subtag

Source

impl Hash for icu_locale_core::subtags::variant::Variant

Source

impl Hash for Variants

Source

impl Hash for BidiClass

Source

impl Hash for CanonicalCombiningClass

Source

impl Hash for EastAsianWidth

Source

impl Hash for GeneralCategoryOutOfBoundsError

Source

impl Hash for GraphemeClusterBreak

Source

impl Hash for HangulSyllableType

Source

impl Hash for IndicConjunctBreak

Source

impl Hash for IndicSyllabicCategory

Source

impl Hash for JoiningType

Source

impl Hash for LineBreak

Source

impl Hash for icu_properties::props::Script

Source

impl Hash for SentenceBreak

Source

impl Hash for VerticalOrientation

Source

impl Hash for WordBreak

Source

impl Hash for DataMarkerId

Source

impl Hash for DataMarkerIdHash

Source

impl Hash for DataMarkerInfo

Source

impl Hash for DataMarkerAttributes

Source

impl Hash for Ipv4AddrRange

Source

impl Hash for Ipv6AddrRange

Source

impl Hash for Ipv4Net

Source

impl Hash for Ipv4Subnets

Source

impl Hash for Ipv6Net

Source

impl Hash for Ipv6Subnets

Source

impl Hash for UriTemplateString

Source

impl Hash for UriTemplateStr

Source

impl Hash for Token

Source

impl Hash for BigInt

Source

impl Hash for BigUint

Source

impl Hash for PotentialCodePoint

Source

impl Hash for rustls_pki_types::server_name::Ipv4Addr

Source

impl Hash for rustls_pki_types::server_name::Ipv6Addr

Source

impl Hash for UnixTime

Source

impl Hash for Map<String, Value>

Source

impl Hash for Number

Source

impl Hash for SmolStr

Source

impl Hash for Variable

Source

impl Hash for CanaryV0

Source

impl Hash for MainnetV0

Source

impl Hash for TestnetV0

Source

impl Hash for Fq2Parameters

Source

impl Hash for Fq6Parameters

Source

impl Hash for Fq12Parameters

Source

impl Hash for FqParameters

Source

impl Hash for snarkvm_curves::bls12_377::fr::FrParameters

Source

impl Hash for Bls12_377G1Parameters

Source

impl Hash for Bls12_377G2Parameters

Source

impl Hash for Bls12_377Parameters

Source

impl Hash for snarkvm_curves::edwards_bls12::fr::FrParameters

Source

impl Hash for EdwardsParameters

Source

impl Hash for BigInteger256

Source

impl Hash for BigInteger384

Source

impl Hash for SockAddr

Source

impl Hash for tokio::net::unix::ucred::UCred

Source

impl Hash for tokio::runtime::id::Id

Source

impl Hash for tokio::runtime::task::id::Id

Source

impl Hash for tokio::time::instant::Instant

Source

impl Hash for tracing_core::callsite::Identifier

Source

impl Hash for tracing_core::field::Field

Source

impl Hash for tracing_core::metadata::Level

Source

impl Hash for tracing_core::metadata::LevelFilter

Source

impl Hash for tracing_core::span::Id

Source

impl Hash for Span

Source

impl Hash for ATerm

Source

impl Hash for B0

Source

impl Hash for B1

Source

impl Hash for Z0

Source

impl Hash for Equal

Source

impl Hash for Greater

Source

impl Hash for Less

Source

impl Hash for UTerm

Source

impl Hash for OpaqueOrigin

Source

impl Hash for Url

URLs hash like their serialization.

Source

impl Hash for CharULE

Source

impl Hash for Index8

Source

impl Hash for Index16

Source

impl Hash for Index32

1.0.0 · Source

impl<'a> Hash for Component<'a>

1.0.0 · Source

impl<'a> Hash for Prefix<'a>

Source

impl<'a> Hash for ServerName<'a>

Source

impl<'a> Hash for PhantomContravariantLifetime<'a>

Source

impl<'a> Hash for PhantomCovariantLifetime<'a>

Source

impl<'a> Hash for PhantomInvariantLifetime<'a>

Source

impl<'a> Hash for AuthorityComponents<'a>

Source

impl<'a> Hash for VarName<'a>

Source

impl<'a> Hash for Metadata<'a>

Source

impl<'a> Hash for MetadataBuilder<'a>

Source

impl<'a> Hash for DnsName<'a>

Source

impl<'a> Hash for CertificateDer<'a>

Source

impl<'a> Hash for CertificateRevocationListDer<'a>

Source

impl<'a> Hash for CertificateSigningRequestDer<'a>

Source

impl<'a> Hash for Der<'a>

Source

impl<'a> Hash for EchConfigListBytes<'a>

Source

impl<'a> Hash for SubjectPublicKeyInfoDer<'a>

Source

impl<'a> Hash for TrustAnchor<'a>

Source

impl<'a, E> Hash for LagrangeBasis<'a, E>

Source

impl<'a, E> Hash for Powers<'a, E>

Source

impl<A> Hash for SmallVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A, B> Hash for EitherOrBoth<A, B>
where A: Hash, B: Hash,

1.0.0 · Source

impl<B> Hash for Cow<'_, B>
where B: Hash + ToOwned + ?Sized,

1.55.0 · Source

impl<B, C> Hash for ControlFlow<B, C>
where B: Hash, C: Hash,

Source

impl<DataStruct> Hash for ErasedMarker<DataStruct>
where DataStruct: Hash + for<'a> Yokeable<'a>,

Source

impl<Dyn> Hash for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> Hash for Address<E>
where E: Hash + Environment,

Source

impl<E> Hash for Boolean<E>
where E: Hash + Environment,

Source

impl<E> Hash for snarkvm_console_program::Field<E>
where E: Hash + Environment, <E as Environment>::Field: Hash,

Source

impl<E> Hash for Group<E>

Source

impl<E> Hash for IdentifierLiteral<E>
where E: Hash + Environment,

Source

impl<E> Hash for Scalar<E>
where E: Hash + Environment, <E as Environment>::Scalar: Hash,

Source

impl<E> Hash for StringType<E>
where E: Hash + Environment,

Source

impl<E> Hash for KZGCommitment<E>

Source

impl<E> Hash for KZGProof<E>

Source

impl<E> Hash for KZGRandomness<E>
where E: Hash + PairingEngine, <E as PairingEngine>::Fr: Hash,

Source

impl<E> Hash for BatchProof<E>
where E: Hash + PairingEngine,

Source

impl<E, I> Hash for Integer<E, I>
where E: Hash + Environment, I: Hash + IntegerType,

Source

impl<E, const DEPTH: u8> Hash for MerklePath<E, DEPTH>
where E: Hash + Environment,

Source

impl<F> Hash for EvaluationDomain<F>
where F: Hash + FftField,

Source

impl<F> Hash for Evaluations<F>
where F: Hash + PrimeField,

Source

impl<F> Hash for DensePolynomial<F>
where F: Hash + Field,

Source

impl<F> Hash for SparsePolynomial<F>
where F: Hash + Field,

Source

impl<F> Hash for LinearCombination<F>
where F: Hash + Field,

1.4.0 · Source

impl<F> Hash for F
where F: FnPtr,

Source

impl<F, const PREFIX: u16> Hash for AleoID<F, PREFIX>
where F: Hash + FieldTrait,

1.0.0 · Source

impl<Idx> Hash for core::ops::range::Range<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for core::ops::range::RangeFrom<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for core::ops::range::RangeInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for RangeTo<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for core::ops::range::RangeToInclusive<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::Range<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::RangeFrom<Idx>
where Idx: Hash,

1.95.0 · Source

impl<Idx> Hash for core::range::RangeInclusive<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::RangeToInclusive<Idx>
where Idx: Hash,

Source

impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
where K: Hash, V: Hash,

1.0.0 · Source

impl<K, V, A> Hash for BTreeMap<K, V, A>
where K: Hash, V: Hash, A: Allocator + Clone,

Source

impl<K, V, S> Hash for LiteMap<K, V, S>
where K: Hash + ?Sized, V: Hash + ?Sized, S: Hash,

Source

impl<L, R> Hash for Either<L, R>
where L: Hash, R: Hash,

Source

impl<N> Hash for Signature<N>
where N: Hash + Network,

Source

impl<N> Hash for ComputeKey<N>
where N: Hash + Network,

Source

impl<N> Hash for GraphKey<N>
where N: Hash + Network,

Source

impl<N> Hash for PrivateKey<N>
where N: Hash + Network,

Source

impl<N> Hash for ViewKey<N>
where N: Hash + Network,

Source

impl<N: Hash + Network> Hash for Access<N>

Source

impl<N: Hash + Network> Hash for EntryType<N>

Source

impl<N: Hash + Network> Hash for FinalizeType<N>

Source

impl<N: Hash + Network> Hash for InputID<N>

Source

impl<N: Hash + Network> Hash for PlaintextType<N>

Source

impl<N: Hash + Network> Hash for Register<N>

Source

impl<N: Hash + Network> Hash for RegisterType<N>

Source

impl<N: Hash + Network> Hash for ValueType<N>

Source

impl<N: Hash + Network> Hash for ArrayType<N>

Source

impl<N: Hash + Network> Hash for Locator<N>

Source

impl<N: Hash + Network> Hash for ProgramID<N>

Source

impl<N: Hash + Network> Hash for ProgramOwner<N>

Source

impl<N: Network> Hash for Literal<N>

Source

impl<N: Network> Hash for Plaintext<N>

Source

impl<N: Network> Hash for snarkvm_console_program::Identifier<N>

Source

impl<O> Hash for F32<O>
where O: Hash,

Source

impl<O> Hash for F64<O>
where O: Hash,

Source

impl<O> Hash for I16<O>
where O: Hash,

Source

impl<O> Hash for I32<O>
where O: Hash,

Source

impl<O> Hash for I64<O>
where O: Hash,

Source

impl<O> Hash for I128<O>
where O: Hash,

Source

impl<O> Hash for Isize<O>
where O: Hash,

Source

impl<O> Hash for U16<O>
where O: Hash,

Source

impl<O> Hash for U32<O>
where O: Hash,

Source

impl<O> Hash for U64<O>
where O: Hash,

Source

impl<O> Hash for U128<O>
where O: Hash,

Source

impl<O> Hash for Usize<O>
where O: Hash,

Source

impl<P> Hash for Bls12<P>
where P: Hash + Bls12Parameters,

Source

impl<P> Hash for G1Prepared<P>
where P: Hash + Bls12Parameters,

Source

impl<P> Hash for G2Prepared<P>

Source

impl<P> Hash for snarkvm_curves::templates::short_weierstrass_jacobian::affine::Affine<P>

Source

impl<P> Hash for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<P> Hash for snarkvm_curves::templates::twisted_edwards_extended::affine::Affine<P>

Source

impl<P> Hash for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<P> Hash for Fp2<P>
where P: Hash + Fp2Parameters, <P as Fp2Parameters>::Fp: Hash,

Source

impl<P> Hash for Fp6<P>

Source

impl<P> Hash for Fp12<P>

Source

impl<P> Hash for Fp256<P>
where P: Hash + Fp256Parameters,

Source

impl<P> Hash for Fp384<P>
where P: Hash + Fp384Parameters,

Source

impl<PH, const DEPTH: u8, const ARITY: u8> Hash for KaryMerklePath<PH, DEPTH, ARITY>
where PH: Hash + PathHash, <PH as PathHash>::Hash: Hash,

1.41.0 · Source

impl<Ptr> Hash for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Hash,

Source

impl<S> Hash for Host<S>
where S: Hash,

Source

impl<S> Hash for RiAbsoluteStr<S>
where S: Spec,

Source

impl<S> Hash for RiAbsoluteString<S>
where S: Spec,

Source

impl<S> Hash for RiFragmentStr<S>
where S: Spec,

Source

impl<S> Hash for RiFragmentString<S>
where S: Spec,

Source

impl<S> Hash for RiStr<S>
where S: Spec,

Source

impl<S> Hash for RiString<S>
where S: Spec,

Source

impl<S> Hash for RiQueryStr<S>
where S: Spec,

Source

impl<S> Hash for RiQueryString<S>
where S: Spec,

Source

impl<S> Hash for RiReferenceStr<S>
where S: Spec,

Source

impl<S> Hash for RiReferenceString<S>
where S: Spec,

Source

impl<S> Hash for RiRelativeStr<S>
where S: Spec,

Source

impl<S> Hash for RiRelativeString<S>
where S: Spec,

Source

impl<Size> Hash for EncodedPoint<Size>
where Size: ModulusSize,

Source

impl<Storage> Hash for __BindgenBitfieldUnit<Storage>
where Storage: Hash,

1.17.0 · Source

impl<T> Hash for Bound<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Option<T>
where T: Hash,

1.36.0 · Source

impl<T> Hash for Poll<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for &T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for &mut T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for [T]
where T: Hash,

1.0.0 · Source

impl<T> Hash for (T₁, T₂, …, Tₙ)
where T: Hash,

This trait is implemented for tuples up to twelve items long.

1.19.0 · Source

impl<T> Hash for Reverse<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for PhantomData<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomCovariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> Hash for ManuallyDrop<T>
where T: Hash + ?Sized,

1.21.0 · Source

impl<T> Hash for Discriminant<T>

1.28.0 · Source

impl<T> Hash for NonZero<T>

1.74.0 · Source

impl<T> Hash for Saturating<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Wrapping<T>
where T: Hash,

1.25.0 · Source

impl<T> Hash for NonNull<T>
where T: ?Sized,

Source

impl<T> Hash for SyncView<T>
where T: Sync + Hash + ?Sized,

Source

impl<T> Hash for CachePadded<T>
where T: Hash,

Source

impl<T> Hash for AllowStdIo<T>
where T: Hash,

Source

impl<T> Hash for indexmap::set::slice::Slice<T>
where T: Hash,

Source

impl<T> Hash for TryWriteableInfallibleAsWriteable<T>
where T: Hash,

Source

impl<T> Hash for WriteableAsTryWriteableInfallible<T>
where T: Hash,

Source

impl<T> Hash for Unalign<T>
where T: Unaligned + Hash,

1.0.0 · Source

impl<T, A> Hash for alloc::boxed::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for BTreeSet<T, A>
where T: Hash, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Hash for LinkedList<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for VecDeque<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Rc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueRc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Arc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueArc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for alloc::vec::Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
Source

impl<T, A> Hash for allocator_api2::stable::boxed::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for allocator_api2::stable::vec::Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

#![feature(build_hasher_simple_hash_one)]
use std::hash::BuildHasher;

let b = std::collections::hash_map::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
1.0.0 · Source

impl<T, E> Hash for Result<T, E>
where T: Hash, E: Hash,

Source

impl<T, N> Hash for GenericArray<T, N>
where T: Hash, N: ArrayLength<T>,

Source

impl<T, const CAP: usize> Hash for ArrayVec<T, CAP>
where T: Hash,

1.0.0 · Source

impl<T, const N: usize> Hash for [T; N]
where T: Hash,

The hash of an array is the same as that of the corresponding slice, as required by the Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));
Source

impl<T, const N: usize> Hash for Simd<T, N>
where T: SimdElement + Hash,

Source

impl<T, const PREFIX: u32> Hash for AleoObject<T, PREFIX>
where T: Hash + Clone + Debug + ToBytes + FromBytes + PartialEq + Eq + Sync + Send,

Source

impl<U> Hash for NInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U> Hash for PInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U, B> Hash for UInt<U, B>
where U: Hash, B: Hash,

Source

impl<U, const N: usize> Hash for NichedOption<U, N>
where U: Hash,

Source

impl<V, A> Hash for TArr<V, A>
where V: Hash, A: Hash,

Source

impl<Y, R> Hash for CoroutineState<Y, R>
where Y: Hash, R: Hash,

Source

impl<const CAP: usize> Hash for ArrayString<CAP>

Source

impl<const LIMBS: usize> Hash for Uint<LIMBS>

Source

impl<const N: usize> Hash for TinyAsciiStr<N>

Source

impl<const N: usize> Hash for RawBytesULE<N>