Display

Trait Display 

1.0.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Implementors

Source

impl Display for snarkvm_console_program::bech32::Error

Source

impl Display for LiteralType

Source

impl Display for AsciiChar

1.34.0 · Source

impl Display for Infallible

1.17.0 · Source

impl Display for FromBytesWithNulError

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for SocketAddr

1.86.0 · Source

impl Display for core::slice::GetDisjointMutError

1.0.0 · Source

impl Display for VarError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.60.0 · Source

impl Display for std::io::error::ErrorKind

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

Source

impl Display for base16ct::error::Error

Source

impl Display for ParseAlphabetError

Source

impl Display for DecodeError

Source

impl Display for DecodeSliceError

Source

impl Display for EncodeSliceError

Source

impl Display for bincode::error::ErrorKind

Source

impl Display for bs58::alphabet::Error

Source

impl Display for bs58::decode::Error

Source

impl Display for bs58::encode::Error

Source

impl Display for const_oid::error::Error

Source

impl Display for der::error::ErrorKind

Source

impl Display for Class

Source

impl Display for Tag

Source

impl Display for TagMode

Source

impl Display for futures_channel::mpsc::TryRecvError

Source

impl Display for FromHexError

Source

impl Display for httparse::Error

Source

impl Display for InvalidStringList

Source

impl Display for icu_collections::codepointtrie::error::Error

Source

impl Display for icu_locale_core::parser::errors::ParseError

Source

impl Display for PreferencesParseError

Source

impl Display for DataErrorKind

Source

impl Display for indexmap::GetDisjointMutError

Source

impl Display for IpNet

Source

impl Display for log::Level

Source

impl Display for log::LevelFilter

Source

impl Display for BernoulliError

Source

impl Display for WeightedError

Source

impl Display for rustls_pki_types::pem::Error

Source

impl Display for webpki::error::Error

Source

impl Display for EarlyDataError

Source

impl Display for EncodeError

Source

impl Display for EncryptError

Source

impl Display for CertificateError

Source

impl Display for rustls::error::Error

Source

impl Display for ExtendedKeyPurpose

Source

impl Display for VerifierBuilderError

Source

impl Display for sec1::error::Error

Source

impl Display for serde_json::value::Value

Source

impl Display for slab::GetDisjointMutError

Source

impl Display for CollectionAllocErr

Source

impl Display for SNARKError

Source

impl Display for PCError

Source

impl Display for SynthesisError

Source

impl Display for AHPError

Source

impl Display for ConsensusVersion

Source

impl Display for GroupError

Source

impl Display for ConstraintFieldError

Source

impl Display for FieldError

Source

impl Display for ParameterError

Source

impl Display for SerializationError

Source

impl Display for tinystr::error::ParseError

Source

impl Display for TryAcquireError

Source

impl Display for tokio::sync::broadcast::error::RecvError

Source

impl Display for tokio::sync::broadcast::error::TryRecvError

Source

impl Display for tokio::sync::mpsc::error::TryRecvError

Source

impl Display for tokio::sync::oneshot::error::TryRecvError

Source

impl Display for ServerErrorsFailureClass

Source

impl Display for GrpcFailureClass

Source

impl Display for StatusInRangeFailureClass

Source

impl Display for url::parser::ParseError

Source

impl Display for SyntaxViolation

Source

impl Display for BigEndian

Source

impl Display for LittleEndian

Source

impl Display for ZeroTrieBuildError

Source

impl Display for UleError

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

Source

impl Display for !

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl Display for snarkvm_console_program::de::value::Error

1.0.0 · Source

impl Display for ParseBoolError

1.0.0 · Source

impl Display for Utf8Error

Source

impl Display for snarkvm_console_program::Error

Source

impl Display for ByteString

Source

impl Display for UnorderedKeyError

1.57.0 · Source

impl Display for alloc::collections::TryReserveError

1.58.0 · Source

impl Display for FromVecWithNulError

1.7.0 · Source

impl Display for IntoStringError

1.0.0 · Source

impl Display for NulError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.0.0 · Source

impl Display for String

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for core::alloc::AllocError

1.35.0 · Source

impl Display for TryFromSliceError

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

Source

impl Display for ByteStr

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

1.34.0 · Source

impl Display for CharTryFromError

1.20.0 · Source

impl Display for ParseCharError

1.9.0 · Source

impl Display for DecodeUtf16Error

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

1.59.0 · Source

impl Display for TryFromCharError

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.4.0 · Source

impl Display for core::net::parser::AddrParseError

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

1.0.0 · Source

impl Display for ParseIntError

1.34.0 · Source

impl Display for TryFromIntError

1.0.0 · Source

impl Display for core::num::float_parse::ParseFloatError

1.26.0 · Source

impl Display for Location<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.65.0 · Source

impl Display for Backtrace

1.0.0 · Source

impl Display for JoinPathsError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.56.0 · Source

impl Display for WriterPanicked

1.0.0 · Source

impl Display for std::io::error::Error

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for NormalizeError

1.7.0 · Source

impl Display for StripPrefixError

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

1.0.0 · Source

impl Display for std::sync::mpsc::RecvError

Source

impl Display for WouldBlock

1.26.0 · Source

impl Display for AccessError

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for allocator_api2::stable::alloc::AllocError

Source

impl Display for allocator_api2::stable::raw_vec::TryReserveError

Source

impl Display for KeyRejected

Source

impl Display for Unspecified

Source

impl Display for HexDisplay<'_>

Source

impl Display for bitflags::parser::ParseError

Source

impl Display for block_buffer::Error

Source

impl Display for TryGetError

Source

impl Display for ColoredString

Source

impl Display for ObjectIdentifier

Source

impl Display for Limb

Source

impl Display for InvalidLength

Source

impl Display for DateTime

Source

impl Display for der::error::Error

Source

impl Display for Length

Source

impl Display for TagNumber

Source

impl Display for MacError

Source

impl Display for InvalidBufferSize

Source

impl Display for InvalidOutputSize

Source

impl Display for elliptic_curve::error::Error

Source

impl Display for futures_channel::mpsc::RecvError

Source

impl Display for futures_channel::mpsc::SendError

Source

impl Display for Canceled

Source

impl Display for SpawnError

Source

impl Display for Aborted

Source

impl Display for getrandom::error::Error

Source

impl Display for LengthLimitError

Source

impl Display for http::error::Error

Source

impl Display for MaxSizeReached

Source

impl Display for HeaderName

Source

impl Display for InvalidHeaderName

Source

impl Display for InvalidHeaderValue

Source

impl Display for ToStrError

Source

impl Display for InvalidMethod

Source

impl Display for Method

Source

impl Display for InvalidStatusCode

Source

impl Display for StatusCode

Formats the status code, including the canonical reason.

Example

assert_eq!(format!("{}", StatusCode::OK), "200 OK");
Source

impl Display for Authority

Source

impl Display for PathAndQuery

Source

impl Display for Scheme

Source

impl Display for InvalidUri

Source

impl Display for InvalidUriParts

Source

impl Display for Uri

Source

impl Display for InvalidChunkSize

Source

impl Display for hyper_util::client::legacy::client::Error

Source

impl Display for InvalidNameError

Source

impl Display for Name

Source

impl Display for hyper::error::Error

Source

impl Display for InvalidSetError

Source

impl Display for RangeError

Source

impl Display for DataLocale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Other

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::private::other::Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Private

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Extensions

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Fields

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::transform::key::Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Transform

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::transform::value::Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Attribute

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Attributes

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::unicode::key::Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Keywords

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Unicode

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SubdivisionId

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SubdivisionSuffix

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::unicode::value::Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for LanguageIdentifier

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Locale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Language

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Region

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Script

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::subtags::Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Variant

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Variants

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for DataError

Source

impl Display for DataIdentifierBorrowed<'_>

Source

impl Display for Errors

Source

impl Display for indexmap::TryReserveError

Source

impl Display for Ipv4Net

Source

impl Display for Ipv6Net

Source

impl Display for PrefixLenError

Source

impl Display for ipnet::parser::AddrParseError

Source

impl Display for CapacityOverflowError

Source

impl Display for iri_string::normalize::error::Error

Source

impl Display for iri_string::template::error::Error

Source

impl Display for UriTemplateString

Source

impl Display for UriTemplateStr

Source

impl Display for iri_string::validate::Error

Source

impl Display for log::ParseLevelError

Source

impl Display for SetLoggerError

Source

impl Display for BigInt

Source

impl Display for BigUint

Source

impl Display for ParseBigIntError

Source

impl Display for num_traits::ParseFloatError

Source

impl Display for PercentEncode<'_>

Source

impl Display for ReadError

Source

impl Display for rand_core::error::Error

Source

impl Display for ThreadPoolBuildError

Source

impl Display for reqwest::error::Error

Source

impl Display for rustls_native_certs::Error

Source

impl Display for rustls_pki_types::server_name::AddrParseError

Source

impl Display for InvalidDnsNameError

Source

impl Display for UnsupportedOperationError

Source

impl Display for OtherError

Source

impl Display for serde_json::error::Error

Source

impl Display for Number

Source

impl Display for signature::error::Error

Source

impl Display for SmolStr

Source

impl Display for ECDSASignature

Source

impl Display for BigInteger256

Source

impl Display for BigInteger384

Source

impl Display for tokio::net::tcp::split_owned::ReuniteError

Source

impl Display for tokio::net::unix::split_owned::ReuniteError

Source

impl Display for TryCurrentError

Source

impl Display for tokio::runtime::id::Id

Source

impl Display for JoinError

Source

impl Display for tokio::runtime::task::id::Id

Source

impl Display for AcquireError

Source

impl Display for tokio::sync::mutex::TryLockError

Source

impl Display for tokio::sync::oneshot::error::RecvError

Source

impl Display for tokio::sync::watch::error::RecvError

Source

impl Display for tokio::time::error::Elapsed

Source

impl Display for tokio::time::error::Error

Source

impl Display for InvalidBackoff

Source

impl Display for tower::timeout::error::Elapsed

Source

impl Display for None

Source

impl Display for SetGlobalDefaultError

Source

impl Display for tracing_core::field::Field

Source

impl Display for FieldSet

Source

impl Display for ValueSet<'_>

Source

impl Display for tracing_core::metadata::Level

Source

impl Display for tracing_core::metadata::LevelFilter

Source

impl Display for tracing_core::metadata::ParseLevelError

Source

impl Display for ParseLevelFilterError

Source

impl Display for Url

Display the serialization of this URL.

Source

impl Display for Utf8CharsError

1.0.0 · Source

impl Display for Arguments<'_>

1.0.0 · Source

impl Display for snarkvm_console_program::fmt::Error

Source

impl Display for dyn Expected + '_

Source

impl Display for dyn Value

Source

impl<'a> Display for Unexpected<'a>

1.34.0 · Source

impl<'a> Display for snarkvm_console_program::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for snarkvm_console_program::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for snarkvm_console_program::str::EscapeUnicode<'a>

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

Source

impl<'a> Display for Ia5StringRef<'a>

Source

impl<'a> Display for PrintableStringRef<'a>

Source

impl<'a> Display for TeletexStringRef<'a>

Source

impl<'a> Display for Utf8StringRef<'a>

Source

impl<'a> Display for VideotexStringRef<'a>

Source

impl<'a, 'e, E> Display for Base64Display<'a, 'e, E>
where E: Engine,

Source

impl<'a, I> Display for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Display,

Source

impl<'a, K, V, A> Display for alloc::collections::btree::map::entry::OccupiedError<'a, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

Source

impl<'a, K, V, A> Display for std::collections::hash::map::OccupiedError<'a, K, V, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, T> Display for tokio::sync::mutex::MappedMutexGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for tokio::sync::rwlock::read_guard::RwLockReadGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for tokio::sync::rwlock::write_guard::RwLockWriteGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
where T: Display + ?Sized,

Source

impl<A, S, V> Display for ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<C> Display for ecdsa::Signature<C>

Source

impl<C> Display for NonZeroScalar<C>
where C: CurveArithmetic,

Source

impl<C> Display for ScalarPrimitive<C>
where C: Curve,

Source

impl<E> Display for Err<E>
where E: Debug,

Source

impl<E> Display for Address<E>
where E: Environment,

Source

impl<E> Display for Boolean<E>
where E: Environment,

Source

impl<E> Display for snarkvm_console_program::Field<E>
where E: Environment,

Source

impl<E> Display for Group<E>
where E: Environment,

Source

impl<E> Display for IdentifierLiteral<E>
where E: Environment,

Source

impl<E> Display for Scalar<E>
where E: Environment,

Source

impl<E> Display for StringType<E>
where E: Environment,

Source

impl<E> Display for Report<E>
where E: Error,

Source

impl<E> Display for CircuitVerifyingKey<E>
where E: PairingEngine,

Source

impl<E, I> Display for Integer<E, I>
where E: Environment, I: IntegerType,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<F, const PREFIX: u16> Display for AleoID<F, PREFIX>
where F: FieldTrait,

Source

impl<I> Display for ExactlyOneError<I>
where I: Iterator,

Source

impl<I> Display for nom::error::Error<I>
where I: Display,

The Display implementation allows the std::error::Error implementation

Source

impl<I> Display for VerboseError<I>
where I: Display,

Available on crate feature alloc only.
Source

impl<I, F> Display for FormatWith<'_, I, F>
where I: Iterator, F: FnMut(<I as Iterator>::Item, &mut dyn FnMut(&dyn Display) -> Result<(), Error>) -> Result<(), Error>,

Source

impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,

Source

impl<N> Display for snarkvm_console_program::Signature<N>
where N: Network,

Source

impl<N> Display for GraphKey<N>
where N: Network,

Source

impl<N> Display for PrivateKey<N>
where N: Network,

Source

impl<N> Display for ViewKey<N>
where N: Network,

Source

impl<N: Network> Display for Access<N>

Source

impl<N: Network> Display for Entry<N, Plaintext<N>>

Source

impl<N: Network> Display for EntryType<N>

Source

impl<N: Network> Display for FinalizeType<N>

Source

impl<N: Network> Display for InputID<N>

Source

impl<N: Network> Display for Literal<N>

Source

impl<N: Network> Display for Owner<N, Plaintext<N>>

Source

impl<N: Network> Display for Plaintext<N>

Source

impl<N: Network> Display for PlaintextType<N>

Source

impl<N: Network> Display for Register<N>

Source

impl<N: Network> Display for RegisterType<N>

Source

impl<N: Network> Display for snarkvm_console_program::Value<N>

Source

impl<N: Network> Display for ValueType<N>

Source

impl<N: Network> Display for HeaderLeaf<N>

Source

impl<N: Network> Display for StatePath<N>

Source

impl<N: Network> Display for TransactionLeaf<N>

Source

impl<N: Network> Display for TransitionLeaf<N>

Source

impl<N: Network> Display for ArrayType<N>

Source

impl<N: Network> Display for Ciphertext<N>

Source

impl<N: Network> Display for DynamicFuture<N>

Source

impl<N: Network> Display for DynamicRecord<N>

Source

impl<N: Network> Display for Future<N>

Source

impl<N: Network> Display for Identifier<N>

Source

impl<N: Network> Display for Locator<N>

Source

impl<N: Network> Display for ProgramID<N>

Source

impl<N: Network> Display for ProgramOwner<N>

Source

impl<N: Network> Display for Record<N, Plaintext<N>>

Source

impl<N: Network> Display for Record<N, Ciphertext<N>>

Source

impl<N: Network> Display for RecordType<N>

Source

impl<N: Network> Display for Request<N>

Source

impl<N: Network> Display for StructType<N>

Source

impl<O> Display for F32<O>
where O: ByteOrder,

Source

impl<O> Display for F64<O>
where O: ByteOrder,

Source

impl<O> Display for I16<O>
where O: ByteOrder,

Source

impl<O> Display for I32<O>
where O: ByteOrder,

Source

impl<O> Display for I64<O>
where O: ByteOrder,

Source

impl<O> Display for I128<O>
where O: ByteOrder,

Source

impl<O> Display for Isize<O>
where O: ByteOrder,

Source

impl<O> Display for U16<O>
where O: ByteOrder,

Source

impl<O> Display for U32<O>
where O: ByteOrder,

Source

impl<O> Display for U64<O>
where O: ByteOrder,

Source

impl<O> Display for U128<O>
where O: ByteOrder,

Source

impl<O> Display for Usize<O>
where O: ByteOrder,

Source

impl<P> Display for snarkvm_curves::templates::short_weierstrass_jacobian::affine::Affine<P>

Source

impl<P> Display for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<P> Display for snarkvm_curves::templates::twisted_edwards_extended::affine::Affine<P>

Source

impl<P> Display for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<P> Display for Fp2<P>
where P: Fp2Parameters,

Source

impl<P> Display for Fp6<P>
where P: Fp6Parameters,

Source

impl<P> Display for Fp12<P>
where P: Fp12Parameters,

Source

impl<P> Display for Fp256<P>
where P: Fp256Parameters,

Source

impl<P> Display for Fp384<P>
where P: Fp384Parameters,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<S> Display for Host<S>
where S: AsRef<str>,

Source

impl<S> Display for Built<'_, RiAbsoluteStr<S>>
where S: Spec,

Source

impl<S> Display for Built<'_, RiStr<S>>
where S: Spec,

Source

impl<S> Display for Built<'_, RiReferenceStr<S>>
where S: Spec,

Source

impl<S> Display for Built<'_, RiRelativeStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiAbsoluteStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiFragmentStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiQueryStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiReferenceStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiRelativeStr<S>>
where S: Spec,

Source

impl<S> Display for PasswordMasked<'_, RiAbsoluteStr<S>>
where S: Spec,

Source

impl<S> Display for PasswordMasked<'_, RiStr<S>>
where S: Spec,

Source

impl<S> Display for PasswordMasked<'_, RiReferenceStr<S>>
where S: Spec,

Source

impl<S> Display for PasswordMasked<'_, RiRelativeStr<S>>
where S: Spec,

Source

impl<S> Display for Normalized<'_, RiAbsoluteStr<S>>
where S: Spec,

Source

impl<S> Display for Normalized<'_, RiStr<S>>
where S: Spec,

Source

impl<S> Display for RiAbsoluteStr<S>
where S: Spec,

Source

impl<S> Display for RiAbsoluteString<S>
where S: Spec,

Source

impl<S> Display for RiFragmentStr<S>
where S: Spec,

Source

impl<S> Display for RiFragmentString<S>
where S: Spec,

Source

impl<S> Display for RiStr<S>
where S: Spec,

Source

impl<S> Display for RiString<S>
where S: Spec,

Source

impl<S> Display for RiQueryStr<S>
where S: Spec,

Source

impl<S> Display for RiQueryString<S>
where S: Spec,

Source

impl<S> Display for RiReferenceStr<S>
where S: Spec,

Source

impl<S> Display for RiReferenceString<S>
where S: Spec,

Source

impl<S> Display for RiRelativeStr<S>
where S: Spec,

Source

impl<S> Display for RiRelativeString<S>
where S: Spec,

Source

impl<S, C> Display for Expanded<'_, S, C>
where S: Spec, C: Context,

Source

impl<S, D> Display for PasswordReplaced<'_, RiAbsoluteStr<S>, D>
where S: Spec, D: Display,

Source

impl<S, D> Display for PasswordReplaced<'_, RiStr<S>, D>
where S: Spec, D: Display,

Source

impl<S, D> Display for PasswordReplaced<'_, RiReferenceStr<S>, D>
where S: Spec, D: Display,

Source

impl<S, D> Display for PasswordReplaced<'_, RiRelativeStr<S>, D>
where S: Spec, D: Display,

Source

impl<Size> Display for EncodedPoint<Size>
where Size: ModulusSize,

Source

impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for ValidityError<Src, Dst>
where Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>

1.0.0 · Source

impl<T> Display for std::sync::mpsc::TrySendError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for tokio::sync::mpsc::error::SendTimeoutError<T>

Available on crate feature time only.
Source

impl<T> Display for tokio::sync::mpsc::error::TrySendError<T>

Source

impl<T> Display for SetError<T>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for core::num::nonzero::NonZero<T>

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.10.0 · Source

impl<T> Display for core::num::wrapping::Wrapping<T>
where T: Display,

1.0.0 · Source

impl<T> Display for std::sync::mpsc::SendError<T>

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for CapacityError<T>

Source

impl<T> Display for CachePadded<T>
where T: Display,

Source

impl<T> Display for ShardedLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ShardedLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for crypto_bigint::non_zero::NonZero<T>
where T: Display + Zero,

Source

impl<T> Display for crypto_bigint::wrapping::Wrapping<T>
where T: Display,

Source

impl<T> Display for futures_channel::mpsc::TrySendError<T>

Source

impl<T> Display for futures_util::io::split::ReuniteError<T>

Source

impl<T> Display for Port<T>

Source

impl<T> Display for iri_string::template::error::CreationError<T>

Available on crate feature alloc only.
Source

impl<T> Display for iri_string::types::generic::error::CreationError<T>

Source

impl<T> Display for TryFromBigIntError<T>

Source

impl<T> Display for AsyncFdTryNewError<T>

Source

impl<T> Display for tokio::sync::broadcast::error::SendError<T>

Source

impl<T> Display for tokio::sync::mpsc::error::SendError<T>

Source

impl<T> Display for tokio::sync::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for OwnedMutexGuard<T>
where T: Display + ?Sized,

Source

impl<T> Display for OwnedRwLockWriteGuard<T>
where T: Display + ?Sized,

Source

impl<T> Display for SetOnceError<T>

Source

impl<T> Display for tokio::sync::watch::error::SendError<T>

Source

impl<T> Display for DisplayValue<T>
where T: Display,

Source

impl<T> Display for LossyWrap<T>
where T: TryWriteable,

Source

impl<T> Display for WithPart<T>
where T: Writeable + ?Sized,

Source

impl<T> Display for TryWriteableInfallibleAsWriteable<T>
where T: TryWriteable<Error = Infallible>,

Source

impl<T> Display for Unalign<T>
where T: Unaligned + Display,

1.0.0 · Source

impl<T, A> Display for alloc::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for allocator_api2::stable::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, B> Display for zerocopy::ref::def::Ref<B, T>

Source

impl<T, E> Display for TryChunksError<T, E>
where E: Display,

Source

impl<T, E> Display for TryReadyChunksError<T, E>
where E: Display,

Source

impl<T, Item> Display for futures_util::stream::stream::split::ReuniteError<T, Item>

Source

impl<T, S> Display for PercentEncoded<T, S>
where T: Display, S: Spec,

Source

impl<T, U> Display for OwnedMappedMutexGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, U> Display for OwnedRwLockReadGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, U> Display for OwnedRwLockMappedWriteGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, const PREFIX: u32> Display for AleoObject<T, PREFIX>
where T: Clone + Debug + ToBytes + FromBytes + PartialEq + Eq + Sync + Send,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>

Source

impl<const CAP: usize> Display for ArrayString<CAP>

Source

impl<const LIMBS: usize> Display for Uint<LIMBS>

Source

impl<const N: usize> Display for TinyAsciiStr<N>