Sub

Trait Sub 

1.0.0 (const: unstable) · Source
pub trait Sub<Rhs = Self> {
    type Output;

    // Required method
    fn sub(self, rhs: Rhs) -> Self::Output;
}
The subtraction operator -.

Note that Rhs is Self by default, but this is not mandatory. For example, std::time::SystemTime implements Sub<Duration>, which permits operations of the form SystemTime = SystemTime - Duration.

Examples

Subtractable points

use std::ops::Sub;

#[derive(Debug, Copy, Clone, PartialEq)]
struct Point {
    x: i32,
    y: i32,
}

impl Sub for Point {
    type Output = Self;

    fn sub(self, other: Self) -> Self::Output {
        Self {
            x: self.x - other.x,
            y: self.y - other.y,
        }
    }
}

assert_eq!(Point { x: 3, y: 3 } - Point { x: 2, y: 3 },
           Point { x: 1, y: 0 });

Implementing Sub with generics

Here is an example of the same Point struct implementing the Sub trait using generics.

use std::ops::Sub;

#[derive(Debug, PartialEq)]
struct Point<T> {
    x: T,
    y: T,
}

// Notice that the implementation uses the associated type `Output`.
impl<T: Sub<Output = T>> Sub for Point<T> {
    type Output = Self;

    fn sub(self, other: Self) -> Self::Output {
        Point {
            x: self.x - other.x,
            y: self.y - other.y,
        }
    }
}

assert_eq!(Point { x: 2, y: 3 } - Point { x: 1, y: 0 },
           Point { x: 1, y: 3 });

Required Associated Types

1.0.0 (const: unstable) · Source

type Output

The resulting type after applying the - operator.

Required Methods

1.0.0 (const: unstable) · Source

fn sub(self, rhs: Rhs) -> Self::Output

Performs the - operation.

Example
assert_eq!(12 - 1, 11);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Sub for ATerm

Source

impl Sub for Assume

Source

impl Sub for BigInt

Source

impl Sub for BigUint

1.3.0 (const: unstable) · Source

impl Sub for Duration

Source

impl Sub for Fe32

1.8.0 · Source

impl Sub for Instant

Source

impl Sub for Length

Source

impl Sub for Limb

Source

impl Sub for ProjectivePoint

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<usize>

Source

impl Sub for k256::arithmetic::scalar::Scalar

Source

impl Sub for UTerm

UTerm - UTerm = UTerm

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<i8>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<i16>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<i32>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<i64>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<i128>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<isize>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<u8>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<u16>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<u32>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<u64>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<u128>

1.0.0 (const: unstable) · Source

impl Sub for core::num::wrapping::Wrapping<usize>

Source

impl Sub for Z0

Z0 - Z0 = Z0

1.0.0 (const: unstable) · Source

impl Sub for f16

1.0.0 (const: unstable) · Source

impl Sub for f32

1.0.0 (const: unstable) · Source

impl Sub for f64

1.0.0 (const: unstable) · Source

impl Sub for f128

1.0.0 (const: unstable) · Source

impl Sub for i8

1.0.0 (const: unstable) · Source

impl Sub for i16

1.0.0 (const: unstable) · Source

impl Sub for i32

1.0.0 (const: unstable) · Source

impl Sub for i64

1.0.0 (const: unstable) · Source

impl Sub for i128

1.0.0 (const: unstable) · Source

impl Sub for isize

1.0.0 (const: unstable) · Source

impl Sub for u8

1.0.0 (const: unstable) · Source

impl Sub for u16

1.0.0 (const: unstable) · Source

impl Sub for u32

1.0.0 (const: unstable) · Source

impl Sub for u64

1.0.0 (const: unstable) · Source

impl Sub for u128

1.0.0 (const: unstable) · Source

impl Sub for usize

Source

impl Sub<&AffinePoint> for &ProjectivePoint

Source

impl Sub<&AffinePoint> for ProjectivePoint

Source

impl Sub<&BigInt> for &BigInt

Source

impl Sub<&BigInt> for &i8

Source

impl Sub<&BigInt> for &i16

Source

impl Sub<&BigInt> for &i32

Source

impl Sub<&BigInt> for &i64

Source

impl Sub<&BigInt> for &i128

Source

impl Sub<&BigInt> for &isize

Source

impl Sub<&BigInt> for &u8

Source

impl Sub<&BigInt> for &u16

Source

impl Sub<&BigInt> for &u32

Source

impl Sub<&BigInt> for &u64

Source

impl Sub<&BigInt> for &u128

Source

impl Sub<&BigInt> for &usize

Source

impl Sub<&BigInt> for BigInt

Source

impl Sub<&BigInt> for i8

Source

impl Sub<&BigInt> for i16

Source

impl Sub<&BigInt> for i32

Source

impl Sub<&BigInt> for i64

Source

impl Sub<&BigInt> for i128

Source

impl Sub<&BigInt> for isize

Source

impl Sub<&BigInt> for u8

Source

impl Sub<&BigInt> for u16

Source

impl Sub<&BigInt> for u32

Source

impl Sub<&BigInt> for u64

Source

impl Sub<&BigInt> for u128

Source

impl Sub<&BigInt> for usize

Source

impl Sub<&BigUint> for &BigUint

Source

impl Sub<&BigUint> for &u8

Source

impl Sub<&BigUint> for &u16

Source

impl Sub<&BigUint> for &u32

Source

impl Sub<&BigUint> for &u64

Source

impl Sub<&BigUint> for &u128

Source

impl Sub<&BigUint> for &usize

Source

impl Sub<&BigUint> for BigUint

Source

impl Sub<&BigUint> for u8

Source

impl Sub<&BigUint> for u16

Source

impl Sub<&BigUint> for u32

Source

impl Sub<&BigUint> for u64

Source

impl Sub<&BigUint> for u128

Source

impl Sub<&BigUint> for usize

Source

impl Sub<&Fe32> for &Fe32

Source

impl Sub<&Fe32> for Fe32

Source

impl Sub<&Limb> for Limb

Source

impl Sub<&ProjectivePoint> for &ProjectivePoint

Source

impl Sub<&ProjectivePoint> for ProjectivePoint

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i8>> for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i16>> for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i32>> for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i64>> for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i128>> for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<isize>> for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u8>> for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u16>> for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u32>> for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u64>> for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u128>> for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<usize>> for &Saturating<usize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<usize>> for Saturating<usize>

Source

impl Sub<&Scalar> for &k256::arithmetic::scalar::Scalar

Source

impl Sub<&Scalar> for k256::arithmetic::scalar::Scalar

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i8>> for &core::num::wrapping::Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i8>> for core::num::wrapping::Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i16>> for &core::num::wrapping::Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i16>> for core::num::wrapping::Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i32>> for &core::num::wrapping::Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i32>> for core::num::wrapping::Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i64>> for &core::num::wrapping::Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i64>> for core::num::wrapping::Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i128>> for &core::num::wrapping::Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i128>> for core::num::wrapping::Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<isize>> for &core::num::wrapping::Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<isize>> for core::num::wrapping::Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u8>> for &core::num::wrapping::Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u8>> for core::num::wrapping::Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u16>> for &core::num::wrapping::Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u16>> for core::num::wrapping::Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u32>> for &core::num::wrapping::Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u32>> for core::num::wrapping::Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u64>> for &core::num::wrapping::Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u64>> for core::num::wrapping::Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u128>> for &core::num::wrapping::Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u128>> for core::num::wrapping::Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<usize>> for &core::num::wrapping::Wrapping<usize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<usize>> for core::num::wrapping::Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Sub<&f16> for &f16

1.0.0 (const: unstable) · Source

impl Sub<&f16> for f16

1.0.0 (const: unstable) · Source

impl Sub<&f32> for &f32

1.0.0 (const: unstable) · Source

impl Sub<&f32> for f32

1.0.0 (const: unstable) · Source

impl Sub<&f64> for &f64

1.0.0 (const: unstable) · Source

impl Sub<&f64> for f64

1.0.0 (const: unstable) · Source

impl Sub<&f128> for &f128

1.0.0 (const: unstable) · Source

impl Sub<&f128> for f128

Source

impl Sub<&i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i8> for &i8

Source

impl Sub<&i8> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i8> for i8

Source

impl Sub<&i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i16> for &i16

Source

impl Sub<&i16> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i16> for i16

Source

impl Sub<&i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i32> for &i32

Source

impl Sub<&i32> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i32> for i32

Source

impl Sub<&i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i64> for &i64

Source

impl Sub<&i64> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i64> for i64

Source

impl Sub<&i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i128> for &i128

Source

impl Sub<&i128> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i128> for i128

Source

impl Sub<&isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&isize> for &isize

Source

impl Sub<&isize> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&isize> for isize

Source

impl Sub<&u8> for &BigInt

Source

impl Sub<&u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u8> for &u8

Source

impl Sub<&u8> for BigInt

Source

impl Sub<&u8> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u8> for u8

Source

impl Sub<&u16> for &BigInt

Source

impl Sub<&u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u16> for &u16

Source

impl Sub<&u16> for BigInt

Source

impl Sub<&u16> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u16> for u16

Source

impl Sub<&u32> for &BigInt

Source

impl Sub<&u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u32> for &u32

Source

impl Sub<&u32> for BigInt

Source

impl Sub<&u32> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u32> for u32

Source

impl Sub<&u64> for &BigInt

Source

impl Sub<&u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u64> for &u64

Source

impl Sub<&u64> for BigInt

Source

impl Sub<&u64> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u64> for u64

Source

impl Sub<&u128> for &BigInt

Source

impl Sub<&u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u128> for &u128

Source

impl Sub<&u128> for BigInt

Source

impl Sub<&u128> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u128> for u128

Source

impl Sub<&usize> for &BigInt

Source

impl Sub<&usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&usize> for &usize

Source

impl Sub<&usize> for BigInt

Source

impl Sub<&usize> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&usize> for usize

Source

impl Sub<AffinePoint> for ProjectivePoint

Source

impl Sub<B0> for UTerm

UTerm - B0 = Term

Source

impl Sub<B1> for UInt<UTerm, B1>

UInt<UTerm, B1> - B1 = UTerm

Source

impl Sub<BigInt> for &BigInt

Source

impl Sub<BigInt> for &i8

Source

impl Sub<BigInt> for &i16

Source

impl Sub<BigInt> for &i32

Source

impl Sub<BigInt> for &i64

Source

impl Sub<BigInt> for &i128

Source

impl Sub<BigInt> for &isize

Source

impl Sub<BigInt> for &u8

Source

impl Sub<BigInt> for &u16

Source

impl Sub<BigInt> for &u32

Source

impl Sub<BigInt> for &u64

Source

impl Sub<BigInt> for &u128

Source

impl Sub<BigInt> for &usize

Source

impl Sub<BigInt> for i8

Source

impl Sub<BigInt> for i16

Source

impl Sub<BigInt> for i32

Source

impl Sub<BigInt> for i64

Source

impl Sub<BigInt> for i128

Source

impl Sub<BigInt> for isize

Source

impl Sub<BigInt> for u8

Source

impl Sub<BigInt> for u16

Source

impl Sub<BigInt> for u32

Source

impl Sub<BigInt> for u64

Source

impl Sub<BigInt> for u128

Source

impl Sub<BigInt> for usize

Source

impl Sub<BigUint> for &BigUint

Source

impl Sub<BigUint> for &u8

Source

impl Sub<BigUint> for &u16

Source

impl Sub<BigUint> for &u32

Source

impl Sub<BigUint> for &u64

Source

impl Sub<BigUint> for &u128

Source

impl Sub<BigUint> for &usize

Source

impl Sub<BigUint> for u8

Source

impl Sub<BigUint> for u16

Source

impl Sub<BigUint> for u32

Source

impl Sub<BigUint> for u64

Source

impl Sub<BigUint> for u128

Source

impl Sub<BigUint> for usize

1.8.0 · Source

impl Sub<Duration> for Instant

1.8.0 · Source

impl Sub<Duration> for SystemTime

Source

impl Sub<Fe32> for &Fe32

Source

impl Sub<Length> for Result<Length, Error>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<usize>> for &Saturating<usize>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i8>> for &core::num::wrapping::Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i16>> for &core::num::wrapping::Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i32>> for &core::num::wrapping::Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i64>> for &core::num::wrapping::Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i128>> for &core::num::wrapping::Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<isize>> for &core::num::wrapping::Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u8>> for &core::num::wrapping::Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u16>> for &core::num::wrapping::Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u32>> for &core::num::wrapping::Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u64>> for &core::num::wrapping::Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u128>> for &core::num::wrapping::Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<usize>> for &core::num::wrapping::Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Sub<f16> for &f16

1.0.0 (const: unstable) · Source

impl Sub<f32> for &f32

1.0.0 (const: unstable) · Source

impl Sub<f64> for &f64

1.0.0 (const: unstable) · Source

impl Sub<f128> for &f128

Source

impl Sub<i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<i8> for &i8

Source

impl Sub<i8> for BigInt

Source

impl Sub<i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<i16> for &i16

Source

impl Sub<i16> for BigInt

Source

impl Sub<i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<i32> for &i32

Source

impl Sub<i32> for BigInt

Source

impl Sub<i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<i64> for &i64

Source

impl Sub<i64> for BigInt

Source

impl Sub<i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<i128> for &i128

Source

impl Sub<i128> for BigInt

Source

impl Sub<isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<isize> for &isize

Source

impl Sub<isize> for BigInt

Source

impl Sub<u8> for &BigInt

Source

impl Sub<u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<u8> for &u8

Source

impl Sub<u8> for BigInt

Source

impl Sub<u8> for BigUint

Source

impl Sub<u16> for &BigInt

Source

impl Sub<u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<u16> for &u16

Source

impl Sub<u16> for BigInt

Source

impl Sub<u16> for BigUint

Source

impl Sub<u32> for &BigInt

Source

impl Sub<u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<u32> for &u32

Source

impl Sub<u32> for BigInt

Source

impl Sub<u32> for BigUint

Source

impl Sub<u64> for &BigInt

Source

impl Sub<u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<u64> for &u64

Source

impl Sub<u64> for BigInt

Source

impl Sub<u64> for BigUint

Source

impl Sub<u128> for &BigInt

Source

impl Sub<u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<u128> for &u128

Source

impl Sub<u128> for BigInt

Source

impl Sub<u128> for BigUint

Source

impl Sub<usize> for &BigInt

Source

impl Sub<usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<usize> for &usize

Source

impl Sub<usize> for BigInt

Source

impl Sub<usize> for BigUint

Source

impl<'a, F> Sub<&'a DensePolynomial<F>> for &DensePolynomial<F>
where F: Field,

Source

impl<'a, F> Sub<&'a Evaluations<F>> for &Evaluations<F>
where F: PrimeField,

Source

impl<'a, F> Sub<&'a LinearCombination<F>> for LinearCombination<F>
where F: Field,

Source

impl<'a, F> Sub<&'a SparsePolynomial<F>> for DensePolynomial<F>
where F: Field,

Source

impl<'a, F> Sub<(F, &'a LinearCombination<F>)> for LinearCombination<F>
where F: Field,

Source

impl<'a, P> Sub<&'a Projective<P>> for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<'a, P> Sub<&'a Projective<P>> for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<'a, P> Sub<&'a mut Fp2<P>> for Fp2<P>
where P: Fp2Parameters,

Source

impl<'a, P> Sub<&'a mut Fp6<P>> for Fp6<P>
where P: Fp6Parameters,

Source

impl<'a, P> Sub<&'a mut Fp12<P>> for Fp12<P>
where P: Fp12Parameters,

Source

impl<'a, P> Sub<&'a mut Fp256<P>> for Fp256<P>
where P: Fp256Parameters,

Source

impl<'a, P> Sub<&'a mut Fp384<P>> for Fp384<P>
where P: Fp384Parameters,

Source

impl<'a, P> Sub<&'a mut Projective<P>> for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<'a, P> Sub<&'a mut Projective<P>> for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<'lhs, 'rhs, T, const N: usize> Sub<&'rhs Simd<T, N>> for &'lhs Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<C> Sub for ScalarValue<C>
where C: Curve,

Source

impl<C> Sub<&ScalarValue<C>> for ScalarValue<C>
where C: Curve,

Source

impl<E, I> Sub for Integer<E, I>
where E: Environment, I: IntegerType,

Source

type Output = Integer<E, I>

Source

impl<E, I> Sub<&Integer<E, I>> for Integer<E, I>
where E: Environment, I: IntegerType,

Source

type Output = Integer<E, I>

Source

impl<E> Sub for Field<E>
where E: Environment,

Source

impl<E> Sub for Group<E>
where E: Environment,

Source

impl<E> Sub for snarkvm_console_program::Scalar<E>
where E: Environment,

Source

impl<E> Sub<&Field<E>> for Field<E>
where E: Environment,

Source

impl<E> Sub<&Group<E>> for Group<E>
where E: Environment,

Source

impl<E> Sub<&Scalar<E>> for snarkvm_console_program::Scalar<E>
where E: Environment,

Source

impl<F> Sub for LinearCombination<F>
where F: Field,

Source

impl<F> Sub<&LinearCombination<F>> for &LinearCombination<F>
where F: Field,

Source

impl<F> Sub<(F, &LinearCombination<F>)> for &LinearCombination<F>
where F: Field,

Source

impl<F> Sub<(F, LinearCombination<F>)> for &LinearCombination<F>
where F: Field,

Source

impl<F> Sub<(F, LinearCombination<F>)> for LinearCombination<F>
where F: Field,

Source

impl<F> Sub<(F, Variable)> for LinearCombination<F>
where F: Field,

Source

impl<F> Sub<LinearCombination<F>> for &LinearCombination<F>
where F: Field,

Source

impl<F> Sub<Variable> for LinearCombination<F>
where F: Field,

Source

impl<MOD, const LIMBS: usize> Sub for ConstMontyForm<MOD, LIMBS>
where MOD: ConstMontyParams<LIMBS>,

Source

type Output = ConstMontyForm<MOD, LIMBS>

Source

impl<MOD, const LIMBS: usize> Sub<&ConstMontyForm<MOD, LIMBS>> for &ConstMontyForm<MOD, LIMBS>
where MOD: ConstMontyParams<LIMBS>,

Source

type Output = ConstMontyForm<MOD, LIMBS>

Source

impl<MOD, const LIMBS: usize> Sub<&ConstMontyForm<MOD, LIMBS>> for ConstMontyForm<MOD, LIMBS>
where MOD: ConstMontyParams<LIMBS>,

Source

type Output = ConstMontyForm<MOD, LIMBS>

Source

impl<MOD, const LIMBS: usize> Sub<ConstMontyForm<MOD, LIMBS>> for &ConstMontyForm<MOD, LIMBS>
where MOD: ConstMontyParams<LIMBS>,

Source

type Output = ConstMontyForm<MOD, LIMBS>

Source

impl<P> Sub for Fp2<P>
where P: Fp2Parameters,

Source

impl<P> Sub for Fp6<P>
where P: Fp6Parameters,

Source

impl<P> Sub for Fp12<P>
where P: Fp12Parameters,

Source

impl<P> Sub for Fp256<P>
where P: Fp256Parameters,

Source

impl<P> Sub for Fp384<P>
where P: Fp384Parameters,

Source

impl<P> Sub for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<P> Sub for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<P> Sub<&&Fp2<P>> for Fp2<P>
where P: Fp2Parameters,

Source

impl<P> Sub<&&Fp6<P>> for Fp6<P>
where P: Fp6Parameters,

Source

impl<P> Sub<&&Fp12<P>> for Fp12<P>
where P: Fp12Parameters,

Source

impl<P> Sub<&&Fp256<P>> for Fp256<P>
where P: Fp256Parameters,

Source

impl<P> Sub<&&Fp384<P>> for Fp384<P>
where P: Fp384Parameters,

Source

impl<P> Sub<&&Projective<P>> for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<P> Sub<&&Projective<P>> for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<P> Sub<&Fp2<P>> for Fp2<P>
where P: Fp2Parameters,

Source

impl<P> Sub<&Fp6<P>> for Fp6<P>
where P: Fp6Parameters,

Source

impl<P> Sub<&Fp12<P>> for Fp12<P>
where P: Fp12Parameters,

Source

impl<P> Sub<&Fp256<P>> for Fp256<P>
where P: Fp256Parameters,

Source

impl<P> Sub<&Fp384<P>> for Fp384<P>
where P: Fp384Parameters,

1.0.0 · Source

impl<T, A> Sub<&BTreeSet<T, A>> for &BTreeSet<T, A>
where T: Ord + Clone, A: Allocator + Clone,

Source

impl<T, S1, S2> Sub<&IndexSet<T, S2>> for &IndexSet<T, S1>
where T: Eq + Hash + Clone, S1: BuildHasher + Default, S2: BuildHasher,

Source

type Output = IndexSet<T, S1>

Source

impl<T, S, A> Sub<&HashSet<T, S, A>> for &hashbrown::set::HashSet<T, S, A>
where T: Eq + Hash + Clone, S: BuildHasher + Default, A: Allocator + Default,

Source

type Output = HashSet<T, S, A>

Source

impl<T, S, A> Sub<&HashSet<T, S, A>> for &hashbrown::set::HashSet<T, S, A>
where T: Eq + Hash + Clone, S: BuildHasher + Default, A: Allocator + Default,

Source

type Output = HashSet<T, S, A>

1.0.0 · Source

impl<T, S> Sub<&HashSet<T, S>> for &std::collections::hash::set::HashSet<T, S>
where T: Eq + Hash + Clone, S: BuildHasher + Default,

Source

type Output = HashSet<T, S>

Source

impl<T, const N: usize> Sub<&Simd<T, N>> for Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<T, const N: usize> Sub<Simd<T, N>> for &Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<T> Sub for Checked<T>

Source

impl<T> Sub for crypto_bigint::wrapping::Wrapping<T>
where T: WrappingSub,

Source

impl<T> Sub<&Checked<T>> for &Checked<T>

Source

impl<T> Sub<&Checked<T>> for Checked<T>

Source

impl<T> Sub<&Wrapping<T>> for &crypto_bigint::wrapping::Wrapping<T>
where T: WrappingSub,

Source

impl<T> Sub<&Wrapping<T>> for crypto_bigint::wrapping::Wrapping<T>
where T: WrappingSub,

Source

impl<T> Sub<Checked<T>> for &Checked<T>

Source

impl<T> Sub<Wrapping<T>> for &crypto_bigint::wrapping::Wrapping<T>
where T: WrappingSub,

Source

impl<U, B> Sub<B0> for UInt<U, B>
where U: Unsigned, B: Bit,

UInt - B0 = UInt

Source

type Output = UInt<U, B>

Source

impl<U, B> Sub<B1> for UInt<UInt<U, B>, B1>
where U: Unsigned, B: Bit,

UInt<U, B1> - B1 = UInt<U, B0>

Source

type Output = UInt<UInt<U, B>, B0>

Source

impl<U> Sub<B1> for UInt<U, B0>
where U: Unsigned + Sub<B1>, <U as Sub<B1>>::Output: Unsigned,

UInt<U, B0> - B1 = UInt<U - B1, B1>

Source

type Output = UInt<<U as Sub<B1>>::Output, B1>

Source

impl<U> Sub<NInt<U>> for Z0
where U: Unsigned + NonZero,

Z0 - N = P

Source

impl<U> Sub<PInt<U>> for Z0
where U: Unsigned + NonZero,

Z0 - P = N

Source

impl<U> Sub<Z0> for NInt<U>
where U: Unsigned + NonZero,

NInt - Z0 = NInt

Source

impl<U> Sub<Z0> for PInt<U>
where U: Unsigned + NonZero,

PInt - Z0 = PInt

Source

impl<Ul, Bl, Ur> Sub<Ur> for UInt<Ul, Bl>
where Ul: Unsigned, Bl: Bit, Ur: Unsigned, UInt<Ul, Bl>: PrivateSub<Ur>, <UInt<Ul, Bl> as PrivateSub<Ur>>::Output: Trim,

Subtracting unsigned integers. We just do our PrivateSub and then Trim the output.

Source

type Output = <<UInt<Ul, Bl> as PrivateSub<Ur>>::Output as Trim>::Output

Source

impl<Ul, Ur> Sub<NInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero, Ur: Unsigned + NonZero + Cmp<Ul> + PrivateIntegerAdd<<Ur as Cmp<Ul>>::Output, Ul>,

N(Ul) - N(Ur): We resolve this with our PrivateAdd

Source

type Output = <Ur as PrivateIntegerAdd<<Ur as Cmp<Ul>>::Output, Ul>>::Output

Source

impl<Ul, Ur> Sub<NInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Add<Ur>, Ur: Unsigned + NonZero, <Ul as Add<Ur>>::Output: Unsigned + NonZero,

P(Ul) - N(Ur) = P(Ul + Ur)

Source

type Output = PInt<<Ul as Add<Ur>>::Output>

Source

impl<Ul, Ur> Sub<PInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero + Add<Ur>, Ur: Unsigned + NonZero, <Ul as Add<Ur>>::Output: Unsigned + NonZero,

N(Ul) - P(Ur) = N(Ul + Ur)

Source

type Output = NInt<<Ul as Add<Ur>>::Output>

Source

impl<Ul, Ur> Sub<PInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Cmp<Ur> + PrivateIntegerAdd<<Ul as Cmp<Ur>>::Output, Ur>, Ur: Unsigned + NonZero,

P(Ul) - P(Ur): We resolve this with our PrivateAdd

Source

type Output = <Ul as PrivateIntegerAdd<<Ul as Cmp<Ur>>::Output, Ur>>::Output

Source

impl<Vl, Al, Vr, Ar> Sub<TArr<Vr, Ar>> for TArr<Vl, Al>
where Vl: Sub<Vr>, Al: Sub<Ar>,

Source

type Output = TArr<<Vl as Sub<Vr>>::Output, <Al as Sub<Ar>>::Output>

Source

impl<const LIMBS: usize> Sub for FixedMontyForm<LIMBS>

Source

impl<const LIMBS: usize> Sub for Int<LIMBS>

Source

type Output = Int<LIMBS>

Source

impl<const LIMBS: usize> Sub for Uint<LIMBS>

Source

type Output = Uint<LIMBS>

Source

impl<const LIMBS: usize> Sub<&FixedMontyForm<LIMBS>> for &FixedMontyForm<LIMBS>

Source

impl<const LIMBS: usize> Sub<&FixedMontyForm<LIMBS>> for FixedMontyForm<LIMBS>

Source

impl<const LIMBS: usize> Sub<&Int<LIMBS>> for Int<LIMBS>

Source

type Output = Int<LIMBS>

Source

impl<const LIMBS: usize> Sub<&Uint<LIMBS>> for Uint<LIMBS>

Source

type Output = Uint<LIMBS>

Source

impl<const LIMBS: usize> Sub<FixedMontyForm<LIMBS>> for &FixedMontyForm<LIMBS>

Source

impl<const N: usize> Sub for Simd<f16, N>

Source

impl<const N: usize> Sub for Simd<f32, N>

Source

impl<const N: usize> Sub for Simd<f64, N>

Source

impl<const N: usize> Sub for Simd<i8, N>
where i8: SimdElement,

Source

impl<const N: usize> Sub for Simd<i16, N>

Source

impl<const N: usize> Sub for Simd<i32, N>

Source

impl<const N: usize> Sub for Simd<i64, N>

Source

impl<const N: usize> Sub for Simd<isize, N>

Source

impl<const N: usize> Sub for Simd<u8, N>
where u8: SimdElement,

Source

impl<const N: usize> Sub for Simd<u16, N>

Source

impl<const N: usize> Sub for Simd<u32, N>

Source

impl<const N: usize> Sub for Simd<u64, N>

Source

impl<const N: usize> Sub for Simd<usize, N>