ToBitsRaw

Trait ToBitsRaw 

pub trait ToBitsRaw: Sized + ToBits {
    // Required methods
    fn write_bits_raw_le(&self, vec: &mut Vec<bool>);
    fn write_bits_raw_be(&self, vec: &mut Vec<bool>);

    // Provided methods
    fn to_bits_raw_le(&self) -> Vec<bool> { ... }
    fn to_bits_raw_be(&self) -> Vec<bool> { ... }
}

Required Methods

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

Writes self into the given vector as a raw boolean array in little-endian order.

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

Writes self into the given vector as a boolean array in big-endian order.

Provided Methods

fn to_bits_raw_le(&self) -> Vec<bool>

Returns self as a boolean array in little-endian order.

fn to_bits_raw_be(&self) -> Vec<bool>

Returns self as a boolean array in big-endian order.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, C0, C1> ToBitsRaw for &'a (C0, C1)
where C0: ToBitsRaw, C1: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2> ToBitsRaw for &'a (C0, C1, C2)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3> ToBitsRaw for &'a (C0, C1, C2, C3)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4> ToBitsRaw for &'a (C0, C1, C2, C3, C4)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw, C10: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1> ToBitsRaw for (C0, C1)
where C0: ToBitsRaw, C1: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2> ToBitsRaw for (C0, C1, C2)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3> ToBitsRaw for (C0, C1, C2, C3)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4> ToBitsRaw for (C0, C1, C2, C3, C4)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5> ToBitsRaw for (C0, C1, C2, C3, C4, C5)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
where C0: ToBitsRaw, C1: ToBitsRaw, C2: ToBitsRaw, C3: ToBitsRaw, C4: ToBitsRaw, C5: ToBitsRaw, C6: ToBitsRaw, C7: ToBitsRaw, C8: ToBitsRaw, C9: ToBitsRaw, C10: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.

Source

impl<C> ToBitsRaw for &[C]
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<C> ToBitsRaw for Vec<C>
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Source

impl<C, const N: usize> ToBitsRaw for [C; N]
where C: ToBitsRaw,

Source

fn write_bits_raw_le(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of little-endian bits.

Source

fn write_bits_raw_be(&self, vec: &mut Vec<bool>)

A helper method to return a concatenated list of big-endian bits.

Implementors