Skip to main content Module state_path Copy item path Source pub use transition_leaf ::*;transition_leaf HeaderLeaf The Merkle leaf for the block header. StatePath The state path proves existence of the transition leaf to either a global or local state root. TransactionLeaf The Merkle leaf for a function or transition in the transaction. BLOCKS_DEPTH The depth of the Merkle tree for the blocks. FINALIZE_ID_DEPTH The depth of the Merkle tree for finalize operations in a transaction.
A transaction can include at most 2^FINALIZE_ID_DEPTH finalize operations total (across all transitions).
Note that MAX_WRITES * MAX_TRANSITIONS can exceed that Merkle-tree capacity. FINALIZE_OPERATIONS_DEPTH The depth of the Merkle tree for finalize operations in a block. HEADER_DEPTH The depth of the Merkle tree for the block header. RATIFICATIONS_DEPTH The depth of the Merkle tree for the ratifications in a block. SUBDAG_CERTIFICATES_DEPTH The depth the Merkle tree for the subdag certificates in a block. TRANSACTIONS_DEPTH The depth of the Merkle tree for transactions in a block.
Note: The technical limit is 2^20 - 1 transactions, to allow compatibility with the
finalize operations tree, which requires 1 leaf for the ratified finalize ID. TRANSACTION_DEPTH The depth of the Merkle tree for the transaction. TRANSITION_DEPTH The depth of the Merkle tree for the transition. BlockPath The Merkle path for the state tree blocks. BlockTree The Merkle tree for the block state. DeploymentTree The Merkle tree for the deployment. ExecutionTree The Merkle tree for the execution. HeaderPath The Merkle path for the block header. HeaderTree The Merkle tree for the block header. RatificationsPath The Merkle path for a ratification in a block. RatificationsTree The Merkle tree for ratifications in a block. TransactionPath The Merkle path for a function or transition in the transaction. TransactionTree The Merkle tree for the transaction. TransactionsPath The Merkle path for a transaction in a block. TransactionsTree The Merkle tree for transactions in a block. TransitionPath The Merkle path for an input or output ID in the transition. TransitionTree The Merkle tree for the transition.