pub struct DynamicFuture<N: Network> { /* private fields */ }Expand description
A dynamic future is a fixed-size representation of a future. Like static
Futures, a dynamic future contains a program name, program network, and function name. These
are however represented as Field elements as opposed to Identifiers to
ensure a fixed size. Dynamic futures also store a checksum of the
arguments to the future instead of the arguments themselves. This ensures
that all dynamic futures have a constant size, regardless of the amount of
data they contain.
The checksum is computed as truncate_252(Sha3_256(bits)), where bits is constructed by:
- Prefixing with the number of arguments as a
u8in little-endian bits. - Appending the type-prefixed
to_bits_le()of each argument. - Padding the result to the next multiple of 8 bits.
The 256-bit SHA-3 output is truncated to the field’s data capacity (252 bits) and packed into a field element.
Implementations
Sourceimpl<N: Network> DynamicFuture<N>
impl<N: Network> DynamicFuture<N>
Sourcepub fn size_in_bits() -> Result<usize>
pub fn size_in_bits() -> Result<usize>
Returns the number of bits in a dynamic future.
Sourcepub fn size_in_bits_raw() -> Result<usize>
pub fn size_in_bits_raw() -> Result<usize>
Returns the number of raw bits in a dynamic future.
Sourceimpl<N: Network> DynamicFuture<N>
impl<N: Network> DynamicFuture<N>
Sourceimpl<N: Network> DynamicFuture<N>
impl<N: Network> DynamicFuture<N>
Sourcepub const fn program_name(&self) -> &Field<N>
pub const fn program_name(&self) -> &Field<N>
Returns the program name.
Sourcepub const fn program_network(&self) -> &Field<N>
pub const fn program_network(&self) -> &Field<N>
Returns the program network.
Sourcepub const fn function_name(&self) -> &Field<N>
pub const fn function_name(&self) -> &Field<N>
Returns the function name.