pub struct DynamicRecord<N: Network> { /* private fields */ }Expand description
A dynamic record is a fixed-size representation of a record. Like static
Records, a dynamic record contains an owner, nonce, and a version.
However, instead of storing the full data, it only stores the Merkle root of
the data. This ensures that all dynamic records have a constant size,
regardless of the amount of data they contain.
Suppose we have the following record with two data entries:
record foo:
owner as address.private;
microcredits as u64.private;
memo as [u8; 32u32].public;The leaves of its Merkle tree are computed as follows:
L_0 := HashPSD8(ToField(name_0) || ToFields(entry_0))
L_1 := HashPSD8(ToField(name_1) || ToFields(entry_1))where name_i is the field encoding of the entry identifier (e.g. "microcredits" → Field),
and ToFields packs the entry’s mode tag bits (2 bits), plaintext bits, and a terminus 1
bit into field elements. The terminus bit ensures collision-resistance across entries of
different lengths.
The tree has depth RECORD_DATA_TREE_DEPTH = 5 and is constructed with
path hasher HashPSD2 and the padding scheme outlined in
snarkVM’s MerkleTree.
Implementations
Sourceimpl<N: Network> DynamicRecord<N>
impl<N: Network> DynamicRecord<N>
Sourceimpl<N: Network> DynamicRecord<N>
impl<N: Network> DynamicRecord<N>
Sourcepub fn size_in_bits() -> Result<usize>
pub fn size_in_bits() -> Result<usize>
Returns the number of bits in a dynamic record.
Sourcepub fn size_in_bits_raw() -> Result<usize>
pub fn size_in_bits_raw() -> Result<usize>
Returns the number of raw bits in a dynamic record.
Sourceimpl<N: Network> DynamicRecord<N>
impl<N: Network> DynamicRecord<N>
Sourcepub const fn new_unchecked(
owner: Address<N>,
root: Field<N>,
nonce: Group<N>,
version: U8<N>,
data: Option<RecordData<N>>,
) -> Self
pub const fn new_unchecked( owner: Address<N>, root: Field<N>, nonce: Group<N>, version: U8<N>, data: Option<RecordData<N>>, ) -> Self
Initializes a dynamic record without checking that the root, tree, and data are consistent.
Sourceimpl<N: Network> DynamicRecord<N>
impl<N: Network> DynamicRecord<N>
Sourcepub const fn data(&self) -> &Option<RecordData<N>>
pub const fn data(&self) -> &Option<RecordData<N>>
Returns the optional record data.
Sourceimpl<N: Network> DynamicRecord<N>
impl<N: Network> DynamicRecord<N>
Sourcepub fn from_record(record: &Record<N, Plaintext<N>>) -> Result<Self>
pub fn from_record(record: &Record<N, Plaintext<N>>) -> Result<Self>
Creates a dynamic record from a static record.
Sourcepub fn to_record(
&self,
owner_is_private: bool,
) -> Result<Record<N, Plaintext<N>>>
pub fn to_record( &self, owner_is_private: bool, ) -> Result<Record<N, Plaintext<N>>>
Creates a static record from this dynamic record.
Sourcepub fn merkleize_data(
data: &IndexMap<Identifier<N>, Entry<N, Plaintext<N>>>,
) -> Result<RecordDataTree<N>>
pub fn merkleize_data( data: &IndexMap<Identifier<N>, Entry<N, Plaintext<N>>>, ) -> Result<RecordDataTree<N>>
Computes the Merkle tree containing the given (ordered) entries as
leaves. More details on the structure of the tree can be found in
DynamicRecord.
Sourcepub fn initialize_hashers() -> (&'static Poseidon8<N>, &'static Poseidon2<N>)
pub fn initialize_hashers() -> (&'static Poseidon8<N>, &'static Poseidon2<N>)
Returns the leaf and path hashers used to merkleize record entries.