pub trait Display {
// Required method
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}Expand description
Format trait for an empty format, {}.
Implementing this trait for a type will automatically implement the
ToString trait for the type, allowing the usage
of the .to_string() method. Prefer implementing
the Display trait for a type, rather than ToString.
Display is similar to Debug, but Display is for user-facing
output, and so cannot be derived.
For more information on formatters, see the module-level documentation.
Completeness and parseability
Display for a type might not necessarily be a lossless or complete representation of the type.
It may omit internal state, precision, or other information the type does not consider important
for user-facing output, as determined by the type. As such, the output of Display might not be
possible to parse, and even if it is, the result of parsing might not exactly match the original
value.
However, if a type has a lossless Display implementation whose output is meant to be
conveniently machine-parseable and not just meant for human consumption, then the type may wish
to accept the same format in FromStr, and document that usage. Having both Display and
FromStr implementations where the result of Display cannot be parsed with FromStr may
surprise users.
Internationalization
Because a type can only have one Display implementation, it is often preferable
to only implement Display when there is a single most “obvious” way that
values can be formatted as text. This could mean formatting according to the
“invariant” culture and “undefined” locale, or it could mean that the type
display is designed for a specific culture/locale, such as developer logs.
If not all values have a justifiably canonical textual format or if you want
to support alternative formats not covered by the standard set of possible
formatting traits, the most flexible approach is display adapters: methods
like str::escape_default or Path::display which create a wrapper
implementing Display to output the specific display format.
Examples
Implementing Display on a type:
use std::fmt;
struct Point {
x: i32,
y: i32,
}
impl fmt::Display for Point {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "({}, {})", self.x, self.y)
}
}
let origin = Point { x: 0, y: 0 };
assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");Required Methods
1.0.0 · Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Formats the value using the given formatter.
Errors
This function should return Err if, and only if, the provided Formatter returns Err.
String formatting is considered an infallible operation; this function only
returns a Result because writing to the underlying stream might fail and it must
provide a way to propagate the fact that an error has occurred back up the stack.
Examples
use std::fmt;
struct Position {
longitude: f32,
latitude: f32,
}
impl fmt::Display for Position {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "({}, {})", self.longitude, self.latitude)
}
}
assert_eq!(
"(1.987, 2.983)",
format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);Implementors
impl Display for snarkvm_console_program::bech32::Error
impl Display for LiteralType
impl Display for AsciiChar
impl Display for Infallible
impl Display for FromBytesWithNulError
impl Display for IpAddr
impl Display for SocketAddr
impl Display for core::slice::GetDisjointMutError
impl Display for VarError
impl Display for std::fs::TryLockError
impl Display for std::io::error::ErrorKind
impl Display for std::sync::mpsc::RecvTimeoutError
impl Display for std::sync::mpsc::TryRecvError
impl Display for base16ct::error::Error
impl Display for ParseAlphabetError
impl Display for DecodeError
impl Display for DecodeSliceError
impl Display for EncodeSliceError
impl Display for bincode::error::ErrorKind
impl Display for bs58::alphabet::Error
impl Display for bs58::decode::Error
impl Display for bs58::encode::Error
impl Display for const_oid::error::Error
impl Display for der::error::ErrorKind
impl Display for Class
impl Display for Tag
impl Display for TagMode
impl Display for futures_channel::mpsc::TryRecvError
impl Display for FromHexError
impl Display for httparse::Error
impl Display for InvalidStringList
impl Display for icu_collections::codepointtrie::error::Error
impl Display for icu_locale_core::parser::errors::ParseError
impl Display for PreferencesParseError
impl Display for DataErrorKind
impl Display for indexmap::GetDisjointMutError
impl Display for IpNet
impl Display for log::Level
impl Display for log::LevelFilter
impl Display for BernoulliError
impl Display for WeightedError
impl Display for rustls_pki_types::pem::Error
impl Display for webpki::error::Error
impl Display for EarlyDataError
impl Display for EncodeError
impl Display for EncryptError
impl Display for CertificateError
impl Display for rustls::error::Error
impl Display for ExtendedKeyPurpose
impl Display for VerifierBuilderError
impl Display for sec1::error::Error
impl Display for serde_json::value::Value
impl Display for slab::GetDisjointMutError
impl Display for CollectionAllocErr
impl Display for SNARKError
impl Display for PCError
impl Display for SynthesisError
impl Display for AHPError
impl Display for ConsensusVersion
impl Display for GroupError
impl Display for ConstraintFieldError
impl Display for FieldError
impl Display for ParameterError
impl Display for SerializationError
impl Display for tinystr::error::ParseError
impl Display for TryAcquireError
impl Display for tokio::sync::broadcast::error::RecvError
impl Display for tokio::sync::broadcast::error::TryRecvError
impl Display for tokio::sync::mpsc::error::TryRecvError
impl Display for tokio::sync::oneshot::error::TryRecvError
impl Display for ServerErrorsFailureClass
impl Display for GrpcFailureClass
impl Display for StatusInRangeFailureClass
impl Display for url::parser::ParseError
impl Display for SyntaxViolation
impl Display for BigEndian
impl Display for LittleEndian
impl Display for ZeroTrieBuildError
impl Display for UleError
impl Display for bool
impl Display for char
impl Display for f16
impl Display for f32
impl Display for f64
impl Display for i8
impl Display for i16
impl Display for i32
impl Display for i64
impl Display for i128
impl Display for isize
impl Display for !
impl Display for str
impl Display for u8
impl Display for u16
impl Display for u32
impl Display for u64
impl Display for u128
impl Display for usize
impl Display for snarkvm_console_program::de::value::Error
impl Display for Arguments<'_>
impl Display for snarkvm_console_program::fmt::Error
impl Display for ByteString
impl Display for UnorderedKeyError
impl Display for alloc::collections::TryReserveError
impl Display for FromVecWithNulError
impl Display for IntoStringError
impl Display for NulError
impl Display for FromUtf8Error
impl Display for FromUtf16Error
impl Display for String
impl Display for LayoutError
impl Display for core::alloc::AllocError
impl Display for TryFromSliceError
impl Display for core::ascii::EscapeDefault
impl Display for ByteStr
impl Display for BorrowError
impl Display for BorrowMutError
impl Display for CharTryFromError
impl Display for ParseCharError
impl Display for DecodeUtf16Error
impl Display for core::char::EscapeDebug
impl Display for core::char::EscapeDefault
impl Display for core::char::EscapeUnicode
impl Display for ToLowercase
impl Display for ToTitlecase
impl Display for ToUppercase
impl Display for TryFromCharError
impl Display for FromBytesUntilNulError
impl Display for Ipv4Addr
impl Display for Ipv6Addr
Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.
impl Display for core::net::parser::AddrParseError
impl Display for SocketAddrV4
impl Display for SocketAddrV6
impl Display for ParseIntError
impl Display for TryFromIntError
impl Display for core::num::float_parse::ParseFloatError
impl Display for Location<'_>
impl Display for PanicInfo<'_>
impl Display for PanicMessage<'_>
impl Display for TryFromFloatSecsError
impl Display for Backtrace
impl Display for JoinPathsError
impl Display for std::ffi::os_str::Display<'_>
impl Display for WriterPanicked
impl Display for std::io::error::Error
impl Display for PanicHookInfo<'_>
impl Display for std::path::Display<'_>
impl Display for NormalizeError
impl Display for StripPrefixError
impl Display for ExitStatus
impl Display for ExitStatusError
impl Display for std::sync::mpsc::RecvError
impl Display for WouldBlock
impl Display for AccessError
impl Display for SystemTimeError
impl Display for allocator_api2::stable::alloc::AllocError
impl Display for allocator_api2::stable::raw_vec::TryReserveError
impl Display for KeyRejected
impl Display for Unspecified
impl Display for HexDisplay<'_>
impl Display for bitflags::parser::ParseError
impl Display for block_buffer::Error
impl Display for TryGetError
impl Display for ColoredString
impl Display for ObjectIdentifier
impl Display for Limb
impl Display for InvalidLength
impl Display for DateTime
impl Display for der::error::Error
impl Display for Length
impl Display for TagNumber
impl Display for MacError
impl Display for InvalidBufferSize
impl Display for InvalidOutputSize
impl Display for elliptic_curve::error::Error
impl Display for futures_channel::mpsc::RecvError
impl Display for futures_channel::mpsc::SendError
impl Display for Canceled
impl Display for SpawnError
impl Display for Aborted
impl Display for getrandom::error::Error
impl Display for LengthLimitError
impl Display for http::error::Error
impl Display for MaxSizeReached
impl Display for HeaderName
impl Display for InvalidHeaderName
impl Display for InvalidHeaderValue
impl Display for ToStrError
impl Display for InvalidMethod
impl Display for Method
impl Display for InvalidStatusCode
impl Display for StatusCode
Formats the status code, including the canonical reason.
Example
assert_eq!(format!("{}", StatusCode::OK), "200 OK");impl Display for Authority
impl Display for PathAndQuery
impl Display for Scheme
impl Display for InvalidUri
impl Display for InvalidUriParts
impl Display for Uri
impl Display for InvalidChunkSize
impl Display for hyper_util::client::legacy::client::Error
impl Display for InvalidNameError
impl Display for Name
impl Display for hyper::error::Error
impl Display for InvalidSetError
impl Display for RangeError
impl Display for DataLocale
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Other
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::extensions::private::other::Subtag
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Private
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Extensions
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Fields
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::extensions::transform::key::Key
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Transform
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::extensions::transform::value::Value
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Attribute
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Attributes
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::extensions::unicode::key::Key
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Keywords
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Unicode
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for SubdivisionId
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for SubdivisionSuffix
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::extensions::unicode::value::Value
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for LanguageIdentifier
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Locale
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Language
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Region
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Script
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::subtags::Subtag
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Variant
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Variants
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for DataError
impl Display for DataIdentifierBorrowed<'_>
impl Display for Errors
impl Display for indexmap::TryReserveError
impl Display for Ipv4Net
impl Display for Ipv6Net
impl Display for PrefixLenError
impl Display for ipnet::parser::AddrParseError
impl Display for CapacityOverflowError
impl Display for iri_string::normalize::error::Error
impl Display for iri_string::template::error::Error
impl Display for UriTemplateString
impl Display for UriTemplateStr
impl Display for iri_string::validate::Error
impl Display for log::ParseLevelError
impl Display for SetLoggerError
impl Display for BigInt
impl Display for BigUint
impl Display for ParseBigIntError
impl Display for num_traits::ParseFloatError
impl Display for PercentEncode<'_>
impl Display for ReadError
impl Display for rand_core::error::Error
impl Display for ThreadPoolBuildError
impl Display for reqwest::error::Error
impl Display for rustls_native_certs::Error
impl Display for rustls_pki_types::server_name::AddrParseError
impl Display for InvalidDnsNameError
impl Display for UnsupportedOperationError
impl Display for OtherError
impl Display for serde_json::error::Error
impl Display for Number
impl Display for signature::error::Error
impl Display for SmolStr
impl Display for ECDSASignature
impl Display for BigInteger256
impl Display for BigInteger384
impl Display for tokio::net::tcp::split_owned::ReuniteError
impl Display for tokio::net::unix::split_owned::ReuniteError
impl Display for TryCurrentError
impl Display for tokio::runtime::id::Id
impl Display for JoinError
impl Display for tokio::runtime::task::id::Id
impl Display for AcquireError
impl Display for tokio::sync::mutex::TryLockError
impl Display for tokio::sync::oneshot::error::RecvError
impl Display for tokio::sync::watch::error::RecvError
impl Display for tokio::time::error::Elapsed
impl Display for tokio::time::error::Error
impl Display for InvalidBackoff
impl Display for tower::timeout::error::Elapsed
impl Display for None
impl Display for SetGlobalDefaultError
impl Display for tracing_core::field::Field
impl Display for FieldSet
impl Display for ValueSet<'_>
impl Display for tracing_core::metadata::Level
impl Display for tracing_core::metadata::LevelFilter
impl Display for tracing_core::metadata::ParseLevelError
impl Display for ParseLevelFilterError
impl Display for Url
Display the serialization of this URL.
impl Display for Utf8CharsError
impl Display for ParseBoolError
impl Display for Utf8Error
impl Display for snarkvm_console_program::Error
impl Display for dyn Expected + '_
impl Display for dyn Value
impl<'a> Display for Unexpected<'a>
impl<'a> Display for EscapeAscii<'a>
impl<'a> Display for Ia5StringRef<'a>
impl<'a> Display for PrintableStringRef<'a>
impl<'a> Display for TeletexStringRef<'a>
impl<'a> Display for Utf8StringRef<'a>
impl<'a> Display for VideotexStringRef<'a>
impl<'a> Display for snarkvm_console_program::str::EscapeDebug<'a>
impl<'a> Display for snarkvm_console_program::str::EscapeDefault<'a>
impl<'a> Display for snarkvm_console_program::str::EscapeUnicode<'a>
impl<'a, 'e, E> Display for Base64Display<'a, 'e, E>where
E: Engine,
impl<'a, I> Display for Format<'a, I>
impl<'a, K, V, A> Display for alloc::collections::btree::map::entry::OccupiedError<'a, K, V, A>
impl<'a, K, V, A> Display for std::collections::hash::map::OccupiedError<'a, K, V, A>
impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
impl<'a, R, T> Display for lock_api::mutex::MappedMutexGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::mutex::MutexGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::RwLockReadGuard<'a, R, T>
impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
impl<'a, T> Display for tokio::sync::mutex::MappedMutexGuard<'a, T>
impl<'a, T> Display for tokio::sync::rwlock::read_guard::RwLockReadGuard<'a, T>
impl<'a, T> Display for tokio::sync::rwlock::write_guard::RwLockWriteGuard<'a, T>
impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
impl<A, S, V> Display for ConvertError<A, S, V>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<B> Display for Cow<'_, B>
impl<C> Display for ecdsa::Signature<C>
impl<C> Display for NonZeroScalar<C>where
C: CurveArithmetic,
impl<C> Display for ScalarPrimitive<C>where
C: Curve,
impl<E> Display for Err<E>where
E: Debug,
impl<E> Display for Report<E>where
E: Error,
impl<E> Display for CircuitVerifyingKey<E>where
E: PairingEngine,
impl<E> Display for Address<E>where
E: Environment,
impl<E> Display for Boolean<E>where
E: Environment,
impl<E> Display for snarkvm_console_program::Field<E>where
E: Environment,
impl<E> Display for Group<E>where
E: Environment,
impl<E> Display for IdentifierLiteral<E>where
E: Environment,
impl<E> Display for Scalar<E>where
E: Environment,
impl<E> Display for StringType<E>where
E: Environment,
impl<E, I> Display for Integer<E, I>where
E: Environment,
I: IntegerType,
impl<F> Display for FromFn<F>
impl<F, const PREFIX: u16> Display for AleoID<F, PREFIX>where
F: FieldTrait,
impl<I> Display for ExactlyOneError<I>where
I: Iterator,
impl<I> Display for nom::error::Error<I>where
I: Display,
The Display implementation allows the std::error::Error implementation
impl<I> Display for VerboseError<I>where
I: Display,
alloc only.impl<I, F> Display for FormatWith<'_, I, F>
impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
impl<L, R> Display for Either<L, R>
impl<N> Display for GraphKey<N>where
N: Network,
impl<N> Display for PrivateKey<N>where
N: Network,
impl<N> Display for ViewKey<N>where
N: Network,
impl<N> Display for snarkvm_console_program::Signature<N>where
N: Network,
impl<N: Network> Display for Access<N>
impl<N: Network> Display for Entry<N, Plaintext<N>>
impl<N: Network> Display for EntryType<N>
impl<N: Network> Display for FinalizeType<N>
impl<N: Network> Display for InputID<N>
impl<N: Network> Display for Literal<N>
impl<N: Network> Display for Owner<N, Plaintext<N>>
impl<N: Network> Display for Plaintext<N>
impl<N: Network> Display for PlaintextType<N>
impl<N: Network> Display for Register<N>
impl<N: Network> Display for RegisterType<N>
impl<N: Network> Display for snarkvm_console_program::Value<N>
impl<N: Network> Display for ValueType<N>
impl<N: Network> Display for HeaderLeaf<N>
impl<N: Network> Display for StatePath<N>
impl<N: Network> Display for TransactionLeaf<N>
impl<N: Network> Display for TransitionLeaf<N>
impl<N: Network> Display for ArrayType<N>
impl<N: Network> Display for Ciphertext<N>
impl<N: Network> Display for DynamicFuture<N>
impl<N: Network> Display for DynamicRecord<N>
impl<N: Network> Display for Future<N>
impl<N: Network> Display for Identifier<N>
impl<N: Network> Display for Locator<N>
impl<N: Network> Display for ProgramID<N>
impl<N: Network> Display for ProgramOwner<N>
impl<N: Network> Display for Record<N, Plaintext<N>>
impl<N: Network> Display for Record<N, Ciphertext<N>>
impl<N: Network> Display for RecordType<N>
impl<N: Network> Display for Request<N>
impl<N: Network> Display for StructType<N>
impl<O> Display for F32<O>where
O: ByteOrder,
impl<O> Display for F64<O>where
O: ByteOrder,
impl<O> Display for I16<O>where
O: ByteOrder,
impl<O> Display for I32<O>where
O: ByteOrder,
impl<O> Display for I64<O>where
O: ByteOrder,
impl<O> Display for I128<O>where
O: ByteOrder,
impl<O> Display for Isize<O>where
O: ByteOrder,
impl<O> Display for U16<O>where
O: ByteOrder,
impl<O> Display for U32<O>where
O: ByteOrder,
impl<O> Display for U64<O>where
O: ByteOrder,
impl<O> Display for U128<O>where
O: ByteOrder,
impl<O> Display for Usize<O>where
O: ByteOrder,
impl<P> Display for snarkvm_curves::templates::short_weierstrass_jacobian::affine::Affine<P>where
P: ShortWeierstrassParameters,
impl<P> Display for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>where
P: ShortWeierstrassParameters,
impl<P> Display for snarkvm_curves::templates::twisted_edwards_extended::affine::Affine<P>where
P: TwistedEdwardsParameters,
impl<P> Display for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>where
P: TwistedEdwardsParameters,
impl<P> Display for Fp2<P>where
P: Fp2Parameters,
impl<P> Display for Fp6<P>where
P: Fp6Parameters,
impl<P> Display for Fp12<P>where
P: Fp12Parameters,
impl<P> Display for Fp256<P>where
P: Fp256Parameters,
impl<P> Display for Fp384<P>where
P: Fp384Parameters,
impl<Ptr> Display for Pin<Ptr>where
Ptr: Display,
impl<S> Display for Host<S>
impl<S> Display for Built<'_, RiAbsoluteStr<S>>where
S: Spec,
impl<S> Display for Built<'_, RiStr<S>>where
S: Spec,
impl<S> Display for Built<'_, RiReferenceStr<S>>where
S: Spec,
impl<S> Display for Built<'_, RiRelativeStr<S>>where
S: Spec,
impl<S> Display for MappedToUri<'_, RiAbsoluteStr<S>>where
S: Spec,
impl<S> Display for MappedToUri<'_, RiFragmentStr<S>>where
S: Spec,
impl<S> Display for MappedToUri<'_, RiStr<S>>where
S: Spec,
impl<S> Display for MappedToUri<'_, RiQueryStr<S>>where
S: Spec,
impl<S> Display for MappedToUri<'_, RiReferenceStr<S>>where
S: Spec,
impl<S> Display for MappedToUri<'_, RiRelativeStr<S>>where
S: Spec,
impl<S> Display for PasswordMasked<'_, RiAbsoluteStr<S>>where
S: Spec,
impl<S> Display for PasswordMasked<'_, RiStr<S>>where
S: Spec,
impl<S> Display for PasswordMasked<'_, RiReferenceStr<S>>where
S: Spec,
impl<S> Display for PasswordMasked<'_, RiRelativeStr<S>>where
S: Spec,
impl<S> Display for Normalized<'_, RiAbsoluteStr<S>>where
S: Spec,
impl<S> Display for Normalized<'_, RiStr<S>>where
S: Spec,
impl<S> Display for RiAbsoluteStr<S>where
S: Spec,
impl<S> Display for RiAbsoluteString<S>where
S: Spec,
impl<S> Display for RiFragmentStr<S>where
S: Spec,
impl<S> Display for RiFragmentString<S>where
S: Spec,
impl<S> Display for RiStr<S>where
S: Spec,
impl<S> Display for RiString<S>where
S: Spec,
impl<S> Display for RiQueryStr<S>where
S: Spec,
impl<S> Display for RiQueryString<S>where
S: Spec,
impl<S> Display for RiReferenceStr<S>where
S: Spec,
impl<S> Display for RiReferenceString<S>where
S: Spec,
impl<S> Display for RiRelativeStr<S>where
S: Spec,
impl<S> Display for RiRelativeString<S>where
S: Spec,
impl<S, C> Display for Expanded<'_, S, C>
impl<S, D> Display for PasswordReplaced<'_, RiAbsoluteStr<S>, D>
impl<S, D> Display for PasswordReplaced<'_, RiStr<S>, D>
impl<S, D> Display for PasswordReplaced<'_, RiReferenceStr<S>, D>
impl<S, D> Display for PasswordReplaced<'_, RiRelativeStr<S>, D>
impl<Size> Display for EncodedPoint<Size>where
Size: ModulusSize,
impl<Src, Dst> Display for AlignmentError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<Src, Dst> Display for SizeError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<Src, Dst> Display for ValidityError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>
impl<T> Display for std::sync::mpsc::TrySendError<T>
impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>
impl<T> Display for std::sync::oneshot::TryRecvError<T>
impl<T> Display for std::sync::poison::TryLockError<T>
impl<T> Display for tokio::sync::mpsc::error::SendTimeoutError<T>
time only.impl<T> Display for tokio::sync::mpsc::error::TrySendError<T>
impl<T> Display for SetError<T>
impl<T> Display for &T
impl<T> Display for &mut T
impl<T> Display for ThinBox<T>
impl<T> Display for core::cell::Ref<'_, T>
impl<T> Display for RefMut<'_, T>
impl<T> Display for core::num::nonzero::NonZero<T>where
T: ZeroablePrimitive + Display,
impl<T> Display for Saturating<T>where
T: Display,
impl<T> Display for core::num::wrapping::Wrapping<T>where
T: Display,
impl<T> Display for std::sync::mpsc::SendError<T>
impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
impl<T> Display for PoisonError<T>
impl<T> Display for ReentrantLockGuard<'_, T>
impl<T> Display for CapacityError<T>
impl<T> Display for CachePadded<T>where
T: Display,
impl<T> Display for ShardedLockReadGuard<'_, T>
impl<T> Display for ShardedLockWriteGuard<'_, T>
impl<T> Display for crypto_bigint::non_zero::NonZero<T>
impl<T> Display for crypto_bigint::wrapping::Wrapping<T>where
T: Display,
impl<T> Display for futures_channel::mpsc::TrySendError<T>
impl<T> Display for futures_util::io::split::ReuniteError<T>
impl<T> Display for Port<T>
impl<T> Display for iri_string::template::error::CreationError<T>
alloc only.