Equal

Trait Equal 

pub trait Equal<Rhs = Self>
where Rhs: ?Sized,
{ type Output; // Required methods fn is_equal(&self, other: &Rhs) -> Self::Output; fn is_not_equal(&self, other: &Rhs) -> Self::Output; }
Trait for equality comparisons.

Required Associated Types

Required Methods

fn is_equal(&self, other: &Rhs) -> Self::Output

Returns true if self and other are equal.

fn is_not_equal(&self, other: &Rhs) -> Self::Output

Returns true if self and other are not equal.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<N> Equal for ComputeKey<N>
where N: Network,

Source

fn is_equal(&self, other: &ComputeKey<N>) -> <ComputeKey<N> as Equal>::Output

Returns true if self and other are equal.

Source

fn is_not_equal( &self, other: &ComputeKey<N>, ) -> <ComputeKey<N> as Equal>::Output

Returns true if self and other are not equal.

Source

type Output = Boolean<N>

Implementors

Source

impl<E> Equal for Address<E>
where E: Environment,

Source

impl<E> Equal for Boolean<E>
where E: Environment,

Source

impl<E> Equal for Field<E>
where E: Environment,

Source

impl<E> Equal for Group<E>
where E: Environment,

Source

impl<E> Equal for IdentifierLiteral<E>
where E: Environment,

Source

impl<E> Equal for Scalar<E>
where E: Environment,

Source

impl<E> Equal for StringType<E>
where E: Environment,

Source

impl<E, I> Equal for Integer<E, I>
where E: Environment, I: IntegerType,

Source

impl<N> Equal for Signature<N>
where N: Network,

Source

impl<N: Network> Equal for Argument<N>

Source

impl<N: Network> Equal for Literal<N>

Source

impl<N: Network> Equal for Plaintext<N>

Source

impl<N: Network> Equal for Value<N>

Source

impl<N: Network> Equal for Ciphertext<N>

Source

impl<N: Network> Equal for DynamicFuture<N>

Source

impl<N: Network> Equal for DynamicRecord<N>

Source

impl<N: Network> Equal for Future<N>

Source

impl<N: Network> Equal for Identifier<N>

Source

impl<N: Network> Equal for ProgramID<N>

Source

impl<N: Network, Private: Visibility<Boolean = Boolean<N>>> Equal for Entry<N, Private>

Source

impl<N: Network, Private: Visibility<Boolean = Boolean<N>>> Equal for Owner<N, Private>

Source

impl<N: Network, Private: Visibility<Boolean = Boolean<N>>> Equal for Record<N, Private>