pub trait _ {
// Required method
fn hash<H>(&self, state: &mut H)
where H: Hasher;
// Provided method
fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher,
Self: Sized { ... }
}Expand description
A hashable type.
Types implementing Hash are able to be hashed with an instance of
Hasher.
Implementing Hash
You can derive Hash with #[derive(Hash)] if all fields implement Hash.
The resulting hash will be the combination of the values from calling
hash on each field.
#[derive(Hash)]
struct Rustacean {
name: String,
country: String,
}If you need more control over how a value is hashed, you can of course
implement the Hash trait yourself:
use std::hash::{Hash, Hasher};
struct Person {
id: u32,
name: String,
phone: u64,
}
impl Hash for Person {
fn hash<H: Hasher>(&self, state: &mut H) {
self.id.hash(state);
self.phone.hash(state);
}
}Hash and Eq
When implementing both Hash and Eq, it is important that the following
property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must also be equal.
HashMap and HashSet both rely on this behavior.
Thankfully, you won’t need to worry about upholding this property when
deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].
Violating this property is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Prefix collisions
Implementations of hash should ensure that the data they
pass to the Hasher are prefix-free. That is,
values which are not equal should cause two different sequences of values to be written,
and neither of the two sequences should be a prefix of the other.
For example, the standard implementation of Hash for &str passes an extra
0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.
Portability
Due to differences in endianness and type sizes, data fed by Hash to a Hasher
should not be considered portable across platforms. Additionally the data passed by most
standard library types should not be considered stable between compiler versions.
This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and
instead should check consistency with Eq.
Serialization formats intended to be portable between platforms or compiler versions should
either avoid encoding hashes or only rely on Hash and Hasher implementations that
provide additional guarantees.
Required Methods
Provided Methods
1.3.0 · Sourcefn hash_slice<H>(data: &[Self], state: &mut H)
fn hash_slice<H>(data: &[Self], state: &mut H)
Feeds a slice of this type into the given Hasher.
This method is meant as a convenience, but its implementation is
also explicitly left unspecified. It isn’t guaranteed to be
equivalent to repeated calls of hash and implementations of
Hash should keep that in mind and call hash themselves
if the slice isn’t treated as a whole unit in the PartialEq
implementation.
For example, a VecDeque implementation might naïvely call
as_slices and then hash_slice on each slice, but this
is wrong since the two slices can change with a call to
make_contiguous without affecting the PartialEq
result. Since these slices aren’t treated as singular
units, and instead part of a larger deque, this method cannot
be used.
Examples
use std::hash::{DefaultHasher, Hash, Hasher};
let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Hash for snarkvm_console_program::bech32::Error
impl Hash for snarkvm_console_program::bech32::Variant
impl Hash for snarkvm_console_program::ErrorKind
impl Hash for LiteralType
impl Hash for snarkvm_console_program::Ordering
impl Hash for AsciiChar
impl Hash for CharCase
impl Hash for Infallible
impl Hash for Locality
impl Hash for core::net::ip_addr::IpAddr
impl Hash for Ipv6MulticastScope
impl Hash for SocketAddr
impl Hash for IntErrorKind
impl Hash for core::sync::atomic::Ordering
impl Hash for std::io::error::ErrorKind
impl Hash for point_conversion_form_t
impl Hash for PollNext
impl Hash for ExtensionType
impl Hash for CalendarAlgorithm
impl Hash for HijriCalendarAlgorithm
impl Hash for CollationCaseFirst
impl Hash for CollationNumericOrdering
impl Hash for CollationType
impl Hash for CurrencyFormatStyle
impl Hash for EmojiPresentationStyle
impl Hash for FirstDay
impl Hash for HourCycle
impl Hash for LineBreakStyle
impl Hash for LineBreakWordHandling
impl Hash for MeasurementSystem
impl Hash for MeasurementUnitOverride
impl Hash for SentenceBreakSupressions
impl Hash for CommonVariantType
impl Hash for GeneralCategory
impl Hash for BufferFormat
impl Hash for IpAddrRange
impl Hash for IpNet
impl Hash for IpSubnets
impl Hash for IriSpec
impl Hash for UriSpec
impl Hash for log::Level
impl Hash for log::LevelFilter
impl Hash for Sign
impl Hash for rustls_pki_types::server_name::IpAddr
impl Hash for serde_json::value::Value
impl Hash for LCTerm
impl Hash for Index
impl Hash for Origin
impl Hash for BigEndian
impl Hash for LittleEndian
impl Hash for bool
impl Hash for char
impl Hash for i8
impl Hash for i16
impl Hash for i32
impl Hash for i64
impl Hash for i128
impl Hash for isize
impl Hash for !
impl Hash for str
impl Hash for u8
impl Hash for u16
impl Hash for u32
impl Hash for u64
impl Hash for u128
impl Hash for ()
impl Hash for usize
impl Hash for u5
impl Hash for snarkvm_console_program::fmt::Error
impl Hash for Console
impl Hash for ByteString
impl Hash for CString
impl Hash for String
impl Hash for Layout
impl Hash for TypeId
impl Hash for ByteStr
impl Hash for CStr
impl Hash for PhantomPinned
impl Hash for Alignment
impl Hash for core::net::ip_addr::Ipv4Addr
impl Hash for core::net::ip_addr::Ipv6Addr
impl Hash for SocketAddrV4
impl Hash for SocketAddrV6
impl Hash for RangeFull
impl Hash for Location<'_>
impl Hash for Duration
impl Hash for OsStr
impl Hash for OsString
impl Hash for FileType
impl Hash for std::os::unix::net::ucred::UCred
impl Hash for Path
impl Hash for PathBuf
impl Hash for PrefixComponent<'_>
impl Hash for ThreadId
impl Hash for std::time::Instant
impl Hash for SystemTime
impl Hash for Bytes
impl Hash for BytesMut
impl Hash for ObjectIdentifier
impl Hash for Limb
impl Hash for HeaderName
impl Hash for HeaderValue
impl Hash for Method
impl Hash for StatusCode
impl Hash for Authority
Case-insensitive hashing
Examples
let a: Authority = "HELLO.com".parse().unwrap();
let b: Authority = "hello.coM".parse().unwrap();
let mut s = DefaultHasher::new();
a.hash(&mut s);
let a = s.finish();
let mut s = DefaultHasher::new();
b.hash(&mut s);
let b = s.finish();
assert_eq!(a, b);impl Hash for PathAndQuery
impl Hash for Scheme
Case-insensitive hashing
impl Hash for Uri
impl Hash for Version
impl Hash for Name
impl Hash for ReasonPhrase
impl Hash for DataLocale
impl Hash for Other
impl Hash for icu_locale_core::extensions::private::other::Subtag
impl Hash for Private
impl Hash for Extensions
impl Hash for Fields
impl Hash for icu_locale_core::extensions::transform::key::Key
impl Hash for Transform
impl Hash for icu_locale_core::extensions::transform::value::Value
impl Hash for Attribute
impl Hash for Attributes
impl Hash for icu_locale_core::extensions::unicode::key::Key
impl Hash for Keywords
impl Hash for Unicode
impl Hash for SubdivisionId
impl Hash for SubdivisionSuffix
impl Hash for icu_locale_core::extensions::unicode::value::Value
impl Hash for LanguageIdentifier
impl Hash for Locale
impl Hash for CurrencyType
impl Hash for NumberingSystem
impl Hash for RegionOverride
impl Hash for RegionalSubdivision
impl Hash for TimeZoneShortId
impl Hash for LocalePreferences
impl Hash for Language
impl Hash for Region
impl Hash for icu_locale_core::subtags::script::Script
impl Hash for icu_locale_core::subtags::Subtag
impl Hash for icu_locale_core::subtags::variant::Variant
impl Hash for Variants
impl Hash for BidiClass
impl Hash for CanonicalCombiningClass
impl Hash for EastAsianWidth
impl Hash for GeneralCategoryOutOfBoundsError
impl Hash for GraphemeClusterBreak
impl Hash for HangulSyllableType
impl Hash for IndicConjunctBreak
impl Hash for IndicSyllabicCategory
impl Hash for JoiningType
impl Hash for LineBreak
impl Hash for icu_properties::props::Script
impl Hash for SentenceBreak
impl Hash for VerticalOrientation
impl Hash for WordBreak
impl Hash for DataMarkerId
impl Hash for DataMarkerIdHash
impl Hash for DataMarkerInfo
impl Hash for DataMarkerAttributes
impl Hash for Ipv4AddrRange
impl Hash for Ipv6AddrRange
impl Hash for Ipv4Net
impl Hash for Ipv4Subnets
impl Hash for Ipv6Net
impl Hash for Ipv6Subnets
impl Hash for UriTemplateString
impl Hash for UriTemplateStr
impl Hash for Token
impl Hash for BigInt
impl Hash for BigUint
impl Hash for PotentialCodePoint
impl Hash for rustls_pki_types::server_name::Ipv4Addr
impl Hash for rustls_pki_types::server_name::Ipv6Addr
impl Hash for UnixTime
impl Hash for Map<String, Value>
impl Hash for Number
impl Hash for SmolStr
impl Hash for Variable
impl Hash for CanaryV0
impl Hash for MainnetV0
impl Hash for TestnetV0
impl Hash for Fq2Parameters
impl Hash for Fq6Parameters
impl Hash for Fq12Parameters
impl Hash for FqParameters
impl Hash for snarkvm_curves::bls12_377::fr::FrParameters
impl Hash for Bls12_377G1Parameters
impl Hash for Bls12_377G2Parameters
impl Hash for Bls12_377Parameters
impl Hash for snarkvm_curves::edwards_bls12::fr::FrParameters
impl Hash for EdwardsParameters
impl Hash for BigInteger256
impl Hash for BigInteger384
impl Hash for SockAddr
impl Hash for tokio::net::unix::ucred::UCred
impl Hash for tokio::runtime::id::Id
impl Hash for tokio::runtime::task::id::Id
impl Hash for tokio::time::instant::Instant
impl Hash for tracing_core::callsite::Identifier
impl Hash for tracing_core::field::Field
impl Hash for tracing_core::metadata::Level
impl Hash for tracing_core::metadata::LevelFilter
impl Hash for tracing_core::span::Id
impl Hash for Span
impl Hash for ATerm
impl Hash for B0
impl Hash for B1
impl Hash for Z0
impl Hash for Equal
impl Hash for Greater
impl Hash for Less
impl Hash for UTerm
impl Hash for OpaqueOrigin
impl Hash for Url
URLs hash like their serialization.
impl Hash for CharULE
impl Hash for Index8
impl Hash for Index16
impl Hash for Index32
impl<'a> Hash for Component<'a>
impl<'a> Hash for Prefix<'a>
impl<'a> Hash for ServerName<'a>
impl<'a> Hash for PhantomContravariantLifetime<'a>
impl<'a> Hash for PhantomCovariantLifetime<'a>
impl<'a> Hash for PhantomInvariantLifetime<'a>
impl<'a> Hash for AuthorityComponents<'a>
impl<'a> Hash for VarName<'a>
impl<'a> Hash for Metadata<'a>
impl<'a> Hash for MetadataBuilder<'a>
impl<'a> Hash for DnsName<'a>
impl<'a> Hash for CertificateDer<'a>
impl<'a> Hash for CertificateRevocationListDer<'a>
impl<'a> Hash for CertificateSigningRequestDer<'a>
impl<'a> Hash for Der<'a>
impl<'a> Hash for EchConfigListBytes<'a>
impl<'a> Hash for SubjectPublicKeyInfoDer<'a>
impl<'a> Hash for TrustAnchor<'a>
impl<'a, E> Hash for LagrangeBasis<'a, E>where
E: Hash + PairingEngine,
<E as PairingEngine>::G1Affine: Hash,
<E as PairingEngine>::Fr: Hash,
impl<'a, E> Hash for Powers<'a, E>
impl<A> Hash for SmallVec<A>
impl<A, B> Hash for EitherOrBoth<A, B>
impl<B> Hash for Cow<'_, B>
impl<B, C> Hash for ControlFlow<B, C>
impl<DataStruct> Hash for ErasedMarker<DataStruct>
impl<Dyn> Hash for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<E> Hash for Address<E>where
E: Hash + Environment,
impl<E> Hash for Boolean<E>where
E: Hash + Environment,
impl<E> Hash for snarkvm_console_program::Field<E>
impl<E> Hash for Group<E>
impl<E> Hash for IdentifierLiteral<E>where
E: Hash + Environment,
impl<E> Hash for Scalar<E>
impl<E> Hash for StringType<E>where
E: Hash + Environment,
impl<E> Hash for KZGCommitment<E>
impl<E> Hash for KZGProof<E>where
E: Hash + PairingEngine,
<E as PairingEngine>::G1Affine: Hash,
<E as PairingEngine>::Fr: Hash,
impl<E> Hash for KZGRandomness<E>
impl<E> Hash for BatchProof<E>where
E: Hash + PairingEngine,
impl<E, I> Hash for Integer<E, I>
impl<E, const DEPTH: u8> Hash for MerklePath<E, DEPTH>where
E: Hash + Environment,
impl<F> Hash for EvaluationDomain<F>
impl<F> Hash for Evaluations<F>where
F: Hash + PrimeField,
impl<F> Hash for DensePolynomial<F>
impl<F> Hash for SparsePolynomial<F>
impl<F> Hash for LinearCombination<F>
impl<F> Hash for Fwhere
F: FnPtr,
impl<F, const PREFIX: u16> Hash for AleoID<F, PREFIX>where
F: Hash + FieldTrait,
impl<Idx> Hash for core::ops::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeTo<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
impl<K, V, A> Hash for BTreeMap<K, V, A>
impl<K, V, S> Hash for LiteMap<K, V, S>
impl<L, R> Hash for Either<L, R>
impl<N> Hash for Signature<N>
impl<N> Hash for ComputeKey<N>
impl<N> Hash for GraphKey<N>
impl<N> Hash for PrivateKey<N>
impl<N> Hash for ViewKey<N>
impl<N: Hash + Network> Hash for Access<N>
impl<N: Hash + Network> Hash for EntryType<N>
impl<N: Hash + Network> Hash for FinalizeType<N>
impl<N: Hash + Network> Hash for InputID<N>
impl<N: Hash + Network> Hash for PlaintextType<N>
impl<N: Hash + Network> Hash for Register<N>
impl<N: Hash + Network> Hash for RegisterType<N>
impl<N: Hash + Network> Hash for ValueType<N>
impl<N: Hash + Network> Hash for ArrayType<N>
impl<N: Hash + Network> Hash for Locator<N>
impl<N: Hash + Network> Hash for ProgramID<N>
impl<N: Hash + Network> Hash for ProgramOwner<N>
impl<N: Network> Hash for Literal<N>
impl<N: Network> Hash for Plaintext<N>
impl<N: Network> Hash for snarkvm_console_program::Identifier<N>
impl<O> Hash for F32<O>where
O: Hash,
impl<O> Hash for F64<O>where
O: Hash,
impl<O> Hash for I16<O>where
O: Hash,
impl<O> Hash for I32<O>where
O: Hash,
impl<O> Hash for I64<O>where
O: Hash,
impl<O> Hash for I128<O>where
O: Hash,
impl<O> Hash for Isize<O>where
O: Hash,
impl<O> Hash for U16<O>where
O: Hash,
impl<O> Hash for U32<O>where
O: Hash,
impl<O> Hash for U64<O>where
O: Hash,
impl<O> Hash for U128<O>where
O: Hash,
impl<O> Hash for Usize<O>where
O: Hash,
impl<P> Hash for Bls12<P>where
P: Hash + Bls12Parameters,
impl<P> Hash for G1Prepared<P>where
P: Hash + Bls12Parameters,
impl<P> Hash for G2Prepared<P>
impl<P> Hash for snarkvm_curves::templates::short_weierstrass_jacobian::affine::Affine<P>
impl<P> Hash for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>where
P: ShortWeierstrassParameters,
impl<P> Hash for snarkvm_curves::templates::twisted_edwards_extended::affine::Affine<P>
impl<P> Hash for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>where
P: TwistedEdwardsParameters,
impl<P> Hash for Fp2<P>
impl<P> Hash for Fp6<P>
impl<P> Hash for Fp12<P>
impl<P> Hash for Fp256<P>where
P: Hash + Fp256Parameters,
impl<P> Hash for Fp384<P>where
P: Hash + Fp384Parameters,
impl<PH, const DEPTH: u8, const ARITY: u8> Hash for KaryMerklePath<PH, DEPTH, ARITY>
impl<Ptr> Hash for Pin<Ptr>
impl<S> Hash for Host<S>where
S: Hash,
impl<S> Hash for RiAbsoluteStr<S>where
S: Spec,
impl<S> Hash for RiAbsoluteString<S>where
S: Spec,
impl<S> Hash for RiFragmentStr<S>where
S: Spec,
impl<S> Hash for RiFragmentString<S>where
S: Spec,
impl<S> Hash for RiStr<S>where
S: Spec,
impl<S> Hash for RiString<S>where
S: Spec,
impl<S> Hash for RiQueryStr<S>where
S: Spec,
impl<S> Hash for RiQueryString<S>where
S: Spec,
impl<S> Hash for RiReferenceStr<S>where
S: Spec,
impl<S> Hash for RiReferenceString<S>where
S: Spec,
impl<S> Hash for RiRelativeStr<S>where
S: Spec,
impl<S> Hash for RiRelativeString<S>where
S: Spec,
impl<Size> Hash for EncodedPoint<Size>where
Size: ModulusSize,
impl<Storage> Hash for __BindgenBitfieldUnit<Storage>where
Storage: Hash,
impl<T> Hash for Bound<T>where
T: Hash,
impl<T> Hash for Option<T>where
T: Hash,
impl<T> Hash for Poll<T>where
T: Hash,
impl<T> Hash for *const Twhere
T: ?Sized,
impl<T> Hash for *mut Twhere
T: ?Sized,
impl<T> Hash for &T
impl<T> Hash for &mut T
impl<T> Hash for [T]where
T: Hash,
impl<T> Hash for (T₁, T₂, …, Tₙ)where
T: Hash,
This trait is implemented for tuples up to twelve items long.
impl<T> Hash for Reverse<T>where
T: Hash,
impl<T> Hash for PhantomData<T>where
T: ?Sized,
impl<T> Hash for PhantomContravariant<T>where
T: ?Sized,
impl<T> Hash for PhantomCovariant<T>where
T: ?Sized,
impl<T> Hash for PhantomInvariant<T>where
T: ?Sized,
impl<T> Hash for ManuallyDrop<T>
impl<T> Hash for Discriminant<T>
impl<T> Hash for NonZero<T>where
T: ZeroablePrimitive + Hash,
impl<T> Hash for Saturating<T>where
T: Hash,
impl<T> Hash for Wrapping<T>where
T: Hash,
impl<T> Hash for NonNull<T>where
T: ?Sized,
impl<T> Hash for SyncView<T>
impl<T> Hash for CachePadded<T>where
T: Hash,
impl<T> Hash for AllowStdIo<T>where
T: Hash,
impl<T> Hash for indexmap::set::slice::Slice<T>where
T: Hash,
impl<T> Hash for TryWriteableInfallibleAsWriteable<T>where
T: Hash,
impl<T> Hash for WriteableAsTryWriteableInfallible<T>where
T: Hash,
impl<T> Hash for Unalign<T>
impl<T, A> Hash for alloc::boxed::Box<T, A>
impl<T, A> Hash for BTreeSet<T, A>
impl<T, A> Hash for LinkedList<T, A>
impl<T, A> Hash for VecDeque<T, A>
impl<T, A> Hash for Rc<T, A>
impl<T, A> Hash for UniqueRc<T, A>
impl<T, A> Hash for Arc<T, A>
impl<T, A> Hash for UniqueArc<T, A>
impl<T, A> Hash for alloc::vec::Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, A> Hash for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> Hash for allocator_api2::stable::vec::Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
#![feature(build_hasher_simple_hash_one)]
use std::hash::BuildHasher;
let b = std::collections::hash_map::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, E> Hash for Result<T, E>
impl<T, N> Hash for GenericArray<T, N>where
T: Hash,
N: ArrayLength<T>,
impl<T, const CAP: usize> Hash for ArrayVec<T, CAP>where
T: Hash,
impl<T, const N: usize> Hash for [T; N]where
T: Hash,
The hash of an array is the same as that of the corresponding slice,
as required by the Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));