pub trait ToBitsRaw: Sized + ToBits {
// Required methods
fn write_bits_raw_le(&self, vec: &mut Vec<bool>);
fn write_bits_raw_be(&self, vec: &mut Vec<bool>);
// Provided methods
fn to_bits_raw_le(&self) -> Vec<bool> { ... }
fn to_bits_raw_be(&self) -> Vec<bool> { ... }
}Required Methods
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
Writes self into the given vector as a raw boolean array in little-endian order.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
Writes self into the given vector as a boolean array in big-endian order.
Provided Methods
Sourcefn to_bits_raw_le(&self) -> Vec<bool>
fn to_bits_raw_le(&self) -> Vec<bool>
Returns self as a boolean array in little-endian order.
Sourcefn to_bits_raw_be(&self) -> Vec<bool>
fn to_bits_raw_be(&self) -> Vec<bool>
Returns self as a boolean array in big-endian order.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<'a, C0, C1> ToBitsRaw for &'a (C0, C1)
impl<'a, C0, C1> ToBitsRaw for &'a (C0, C1)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2> ToBitsRaw for &'a (C0, C1, C2)
impl<'a, C0, C1, C2> ToBitsRaw for &'a (C0, C1, C2)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2, C3> ToBitsRaw for &'a (C0, C1, C2, C3)
impl<'a, C0, C1, C2, C3> ToBitsRaw for &'a (C0, C1, C2, C3)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2, C3, C4> ToBitsRaw for &'a (C0, C1, C2, C3, C4)
impl<'a, C0, C1, C2, C3, C4> ToBitsRaw for &'a (C0, C1, C2, C3, C4)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2, C3, C4, C5> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5)
impl<'a, C0, C1, C2, C3, C4, C5> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6)
impl<'a, C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7)
impl<'a, C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8)
impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
impl<'a, C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for &'a (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1> ToBitsRaw for (C0, C1)
impl<C0, C1> ToBitsRaw for (C0, C1)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2> ToBitsRaw for (C0, C1, C2)
impl<C0, C1, C2> ToBitsRaw for (C0, C1, C2)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2, C3> ToBitsRaw for (C0, C1, C2, C3)
impl<C0, C1, C2, C3> ToBitsRaw for (C0, C1, C2, C3)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2, C3, C4> ToBitsRaw for (C0, C1, C2, C3, C4)
impl<C0, C1, C2, C3, C4> ToBitsRaw for (C0, C1, C2, C3, C4)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2, C3, C4, C5> ToBitsRaw for (C0, C1, C2, C3, C4, C5)
impl<C0, C1, C2, C3, C4, C5> ToBitsRaw for (C0, C1, C2, C3, C4, C5)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6)
impl<C0, C1, C2, C3, C4, C5, C6> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7)
impl<C0, C1, C2, C3, C4, C5, C6, C7> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8)
impl<C0, C1, C2, C3, C4, C5, C6, C7, C8> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10> ToBitsRaw for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10)
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits without variant or identifier bits from the circuits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of bits-endian bits without variant or identifier bits from the circuits.
Sourceimpl<C> ToBitsRaw for &[C]where
C: ToBitsRaw,
impl<C> ToBitsRaw for &[C]where
C: ToBitsRaw,
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of big-endian bits.
Sourceimpl<C> ToBitsRaw for Vec<C>where
C: ToBitsRaw,
impl<C> ToBitsRaw for Vec<C>where
C: ToBitsRaw,
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of big-endian bits.
Sourceimpl<C, const N: usize> ToBitsRaw for [C; N]where
C: ToBitsRaw,
impl<C, const N: usize> ToBitsRaw for [C; N]where
C: ToBitsRaw,
Sourcefn write_bits_raw_le(&self, vec: &mut Vec<bool>)
fn write_bits_raw_le(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of little-endian bits.
Sourcefn write_bits_raw_be(&self, vec: &mut Vec<bool>)
fn write_bits_raw_be(&self, vec: &mut Vec<bool>)
A helper method to return a concatenated list of big-endian bits.